/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import Ubuntu.Components.Pickers 1.3

Item {
    id: dateDialog

    property date curDate: new Date()

    signal acceptClicked(date newDate)

    Component.onCompleted: PopupUtils.open(component,dateDialog,{curDate: curDate});

    Component {
        id: component
        Dialog {
            id: dialog
            title: i18n.tr("Date")
            property date curDate: new Date()

            DatePicker {
                id: datePicker
                date: curDate
                minimum: {
                    var d = new Date();
                    d.setFullYear(d.getFullYear() - 50);
                    return d;
                }
                maximum: new Date()
                mode: "Days|Months|Years"
                onDateChanged: {
                    var d = curDate;
                    d.setDate(datePicker.date.getDate());
                    d.setMonth(datePicker.date.getMonth());
                    d.setFullYear(datePicker.date.getFullYear());
                    if (!entries.dateCompare({"compare": d})){
                        okButton.enabled = true;
                        attentionDate.visible = false;
                        curDate = d;
                    }
                    else{
                        date = new Date();
                        //attentionDate.visible = true;
                        //okButton.enabled = false;
                    }
                }
            }
            Label{
                id: attentionDate
                width: parent.width
                color: UbuntuColors.red
                horizontalAlignment: Text.AlignHCenter
                text: i18n.tr("Date is in the future !!!")
                visible: false
            }
            Button {
                id: okButton
                text: "Ok"
                onClicked: {
                    dateDialog.acceptClicked(curDate)
                    PopupUtils.close(dialog)
                }
            }
        }
    }
}
