/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import QtQuick.Layouts 1.1
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem
import Diabetes_Diary_App 1.0
import "../utils.js" as Utils
import "../Components"

PageWithBottomEdge {
    id: diaryPage
    title: i18n.tr("Diary")
    bottomEdgeTitle: i18n.tr("Add new entry")
    bottomEdgePageSource: Qt.resolvedUrl("./EditEntryPage.qml")

    state: "default"
    states: [
        PageHeadState {
            name: "default"
            head: diaryPage.head
            actions: Action {
                iconName: "search"
                onTriggered: diaryPage.state = "search"
            }
        },
        PageHeadState {
            id: headerState
            name: "search"
            head: diaryPage.head
            backAction: Action {
                id: leaveSearchAction
                text: "back"
                iconName: "back"
                onTriggered: {
                    entries.setFilterFixedString("");
                    searchText.text = "";
                    diaryPage.state = "default"
                }
            }
            contents: TextField {
                id: searchText
                placeholderText: i18n.tr("Search notes")
                inputMethodHints: Qt.ImhNoPredictiveText
                primaryItem: Icon {
                    height: parent.height - units.gu(2)
                    width: height
                    name: "search"
                }
                width: parent ? (parent.width - units.gu(2)) : undefined
                onTextChanged: {
                    entries.setFilterFixedString(text)
                }
                onVisibleChanged: forceActiveFocus()
            }
        }
    ]
    property bool footerActive: diaryListModel.bCanFetchMore

    function showEditPage(entry){
        var page = pageStack.push(Qt.createComponent(Qt.resolvedUrl("./EditEntryPage.qml")),
                                  {title: i18n.tr("Edit Entry"), entry: entry, bUpdateValues: true});
        page.setEntryFromModel();
    }

    DiaryListFilterModel{
        id: entries
        sourceModel: diaryListModel
    }

    EntryList {
        id: entryList
        clip: true
        anchors.fill: parent
        height: parent.height - y
        maximumFlickVelocity: height * 4
        flickDeceleration: height
        cacheBuffer: 5000
        model: entries

        section.property: "date"
        section.criteria: ViewSection.FullString
        section.delegate: ListItem.Empty{
                anchors { left: parent.left; right: parent.right }
                height: units.dp(45)
                highlightWhenPressed: false
                RowLayout {
                    anchors {
                        left: parent.left;
                        right: parent.right;
                        verticalCenter: parent.verticalCenter;
                        margins: units.gu(1)
                    }
                    Label {
                        text: entries.sectionTitle({"date":section})
                        font.bold: true
                        Layout.fillWidth: true
                    }
                    Label {
                        id: result
                        text: entries.sectionAverage({"date":section},settings.measurementUnit)
                    }
                }
        }
        footer: Loader {
            width: parent.width
            active: footerActive
            sourceComponent: ListItem.Standard{
                id: fetchMore
                text: i18n.tr("Load more...")
                onClicked: {
                    diaryListModel.reloadAndFetchMore();
                    footerActive = diaryListModel.bCanFetchMore;
                }
            }
        }
        onDeleteEntry: {
            diaryListModel.deleteEntry(entry.id);
            //entryMetric.increment(-1);
        }
        onEditEntry: showEditPage(entry);
    }

}//Page
