/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import QtQuick.Layouts 1.0
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem
import Ubuntu.Components.Themes.Ambiance 1.1
import Diabetes_Diary_App 1.0
import "../utils.js" as Utils
import "../Popover"

Page {
    id: editEntryPage
    title: i18n.tr("New Entry")
    flickable: null
    clip: true
    head.actions: Action {
            iconName: "ok"
            enabled: isText
            onTriggered: {
                Qt.inputMethod.hide();
                if (bUpdateValues) diaryListModel.updateEntry(entry.id,createData());
                else {
                    diaryListModel.createEntry(createData());
                    entryMetric.increment();
                }
                pageStack.pop();
            }
        }
     head.backAction: Action {
            iconName: "back"
            onTriggered: {
                pageStack.pop();
            }
        }
/**** Variablen deklaration ****/
    property var entry: null
    property int itfSize: 5
    property bool bUpdateValues: false
    property string sPump: ""
    property date date: new Date()
    property var locale: Qt.locale()
    property bool isText: inpSugar.text !== "" | inpKE.text !== "" |
                          inpBolus.text !== "" | inpBasal.text !== "" | inpNote.text !== ""

    function setEntryFromModel(){
        var dateString  = "";
        if(diaryListModel.internationalUnit)
            inpSugar.text = (entry.glucoseMeasurementMmol === 0) ? "" : entry.glucoseMeasurementMmol.toFixed(settings.fixpoint);
        else
            inpSugar.text = (entry.glucoseMeasurementMg === 0) ? "" : entry.glucoseMeasurementMg.toFixed(settings.fixpoint);
        var mealCarbs = (diaryListModel.selectedGrams) ? entry.mealCarbsGrams.toFixed(1) : entry.mealCarbs
        inpKE.text      = (mealCarbs === 0) ? "" : mealCarbs;
        inpBolus.text   = (entry.bolus === 0) ? "" : entry.bolus;
        inpNote.text    = entry.note;
        sPump           = entry.temporaryPumpBasal;
        dateString      = Qt.formatDateTime(entry.timeStamp,"dd.MM.yyyy hh:mm");
        date            = Date.fromLocaleString(locale, dateString,"dd.MM.yyyy hh:mm");
        dateTimeItem.curDate = date;

        if (!settings.diabetesTherapy){
            inpBasal.text = (entry.basalInjection === 0) ? "" : entry.basalInjection;
        }
        else if ((settings.diabetesTherapy) & !(sPump === "")){
            var pumpStr = Utils.getPumpString(sPump);
            inpBasal.text = pumpStr[0] + ":" + pumpStr[1] + " -> " + pumpStr[2];
        }
    }
/**** FUNCTIONS *****/
    function createData(){
        return {"date": dateTimeItem.curDate, "glucoseMeasurement": inpSugar.text,"mealCarbs": inpKE.text,
                "bolus": inpBolus.text,"note": inpNote.text,
                "basalInjection": (!settings.diabetesTherapy) ? inpBasal.text : "",
                "temporaryPumpBasal": (settings.diabetesTherapy) ? sPump : ""}
    }
    function addPumpValues(hours,minutes,percent){
        inpBasal.text = hours + ":" + minutes + " -> " + percent;
        sPump = hours + ":" + minutes + "/" + percent;
    }
    function createTempBasalItem(str,bUpdate){
        var component = Qt.createComponent(Qt.resolvedUrl("./PumpBasalTempDialog.qml"));
        var popup;
        if (!bUpdate) popup = component.createObject(editEntryPage);
        else popup = component.createObject(editEntryPage,{pickerValues: Utils.getPumpString((str)),bEditRate: true});
        popup.applyTempRate.connect(editEntryPage.addPumpValues);
    }



    Flickable {
        id: flickable
        flickableDirection: Flickable.VerticalFlick
        anchors.fill: editEntryPage
        contentHeight: colAdd.height + Qt.inputMethod.keyboardRectangle.height
        anchors.margins: units.gu(1)
        anchors.topMargin: units.gu(2)
        boundsBehavior: Flickable.StopAtBounds
        Column {
            id: colAdd
            spacing: units.gu(2)
            width: parent.width

            DateTimeItem{
                id: dateTimeItem
                height:  units.gu(6)
                width: parent.width
                iconheight: height
                curDate: date
                onDateClicked: {
                    Haptics.play();
                    Qt.inputMethod.hide();
                    var component = Qt.createComponent(Qt.resolvedUrl("./DatePickerDialog.qml"));
                    var popup = component.createObject(editEntryPage,{curDate: dateTimeItem.curDate});
                    popup.acceptClicked.connect(function(newDate){
                        dateTimeItem.curDate = newDate;
                    });
                }
                onTimeClicked: {
                    Haptics.play();
                    Qt.inputMethod.hide();
                    var component = Qt.createComponent(Qt.resolvedUrl("./TimePickerDialog.qml"));
                    var popup = component.createObject(editEntryPage,{curDate: dateTimeItem.curDate});
                    popup.acceptClicked.connect(function(newTime){
                        dateTimeItem.curDate = newTime;
                    });
                }
            }
            ListItem.ThinDivider{}
            Grid{
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: units.gu(3)
                columns: 2
                horizontalItemAlignment: Grid.AlignRight
                verticalItemAlignment: Grid.AlignVCenter
                Label{
                    text: i18n.tr("Blood glucose")
                    font.pixelSize: FontUtils.sizeToPixels("large")
                }
                TextField {
                    id: inpSugar
                    width: units.gu(17)
                    font.pixelSize: FontUtils.sizeToPixels("large")
                    placeholderText: "-"
                    inputMethodHints: Qt.ImhFormattedNumbersOnly
                    horizontalAlignment: TextInput.AlignLeft
                    font.bold: true
                    hasClearButton: false
                    style: TextFieldStyle {
                        background: null
                    }
                    secondaryItem: Label{
                        text: settings.measurementUnit
                        font.pixelSize: FontUtils.sizeToPixels("large")
                    }
                    validator: DoubleValidator {
                        bottom: 0
                        top: 999
                        decimals: 1
                        notation: DoubleValidator.StandardNotation
                    }
                }
                Label{
                    text: i18n.tr("Meal carbs")
                    font.pixelSize: FontUtils.sizeToPixels("large")
                }
                TextField {
                    id: inpKE
                    width: units.gu(17)
                    font.pixelSize: FontUtils.sizeToPixels("large")
                    placeholderText: "-"
                    inputMethodHints: Qt.ImhFormattedNumbersOnly
                    horizontalAlignment: TextInput.AlignLeft
                    font.bold: true
                    hasClearButton: false
                    style: TextFieldStyle {
                        background: null
                    }
                    secondaryItem: Label{
                        text: settings.carbsUnit
                        font.pixelSize: FontUtils.sizeToPixels("large")
                    }
                    validator: DoubleValidator {
                        bottom: 0
                        top: 999
                        decimals: 1
                        notation: DoubleValidator.StandardNotation
                    }
                }
                Label{
                    text: i18n.tr("Bolus")
                    font.pixelSize: FontUtils.sizeToPixels("large")
                }

                TextField {
                    id: inpBolus
                    width: units.gu(17)
                    font.pixelSize: FontUtils.sizeToPixels("large")
                    placeholderText: "-"
                    font.bold: true
                    hasClearButton: false
                    inputMethodHints: Qt.ImhFormattedNumbersOnly
                    horizontalAlignment: TextInput.AlignLeft
                    style: TextFieldStyle {
                        background: null
                    }
                    secondaryItem: Label{
                        text: i18n.tr("iU")
                        font.pixelSize: FontUtils.sizeToPixels("large")
                    }
                    validator: DoubleValidator {
                        bottom: 0
                        top: 999
                        decimals: 1
                        notation: DoubleValidator.StandardNotation
                    }
                }
                Label{
                    text: (settings.diabetesTherapy) ? i18n.tr("temp. Basal") : i18n.tr("Basal")
                    font.pixelSize: FontUtils.sizeToPixels("large")
                    horizontalAlignment: TextInput.AlignLeft
                    Layout.fillWidth: true
                }
                TextField {
                    id: inpBasal
                    width: units.gu(17)
                    activeFocusOnPress: !settings.diabetesTherapy
                    selectByMouse: !settings.diabetesTherapy
                    font.pixelSize: (settings.diabetesTherapy) ? FontUtils.sizeToPixels("medium") : FontUtils.sizeToPixels("large")
                    placeholderText: "-"
                    font.bold: true
                    hasClearButton: false
                    inputMethodHints: Qt.ImhFormattedNumbersOnly
                    horizontalAlignment: TextInput.AlignLeft
                    MouseArea {
                        anchors.fill: parent
                        hoverEnabled: true
                        enabled: settings.diabetesTherapy
                        onClicked:{
                            Qt.inputMethod.hide();
                            Haptics.play();
                            if (inpBasal.text === "") editEntryPage.createTempBasalItem("",false);
                            else editEntryPage.createTempBasalItem(sPump,true);
                        }
                        onPressAndHold: {
                            inpBasal.selectAll();
                            var popover = PopupUtils.open(Qt.resolvedUrl("../Popover/DeletePopover.qml"),inpBasal);
                            popover.clicked.connect(function(){
                                sPump = "";
                                inpBasal.text = sPump;
                            });
                        }
                    }
                    style: TextFieldStyle {
                        background: null
                    }
                    secondaryItem: Label{
                        text: i18n.tr("iU")
                        font.pixelSize: FontUtils.sizeToPixels("large")
                        visible: !settings.diabetesTherapy
                    }
                    validator: DoubleValidator {
                        bottom: 0
                        top: 999
                        decimals: 1
                        notation: DoubleValidator.StandardNotation
                    }
                }
                Label{
                    text: i18n.tr("Note")
                    font.pixelSize: FontUtils.sizeToPixels("large")
                    horizontalAlignment: TextInput.AlignRight
                }
                TextField {
                    id: inpNote
                    width: units.gu(17)
                    font.pixelSize: FontUtils.sizeToPixels("medium")
                    placeholderText: "-"
                    font.bold: true
                    hasClearButton: false
                    style: TextFieldStyle {
                        background: null
                    }
                }
            }
            ListItem.ThinDivider{}
        }
    }//Flickable
}
