/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import QtQuick.Layouts 1.0
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3

ListView {
    id: entryList

    signal deleteEntry(var entry)
    signal editEntry(var entry)

    delegate: ListItem{
        id: items
        height: units.dp(55)
        width: parent.width
        focus: true
        leadingActions: ListItemActions {
            actions: [ Action {
                    iconName: "delete"
                    onTriggered: entryList.deleteEntry(model);
                }]
        }
        trailingActions: ListItemActions {
            actions: [ Action {
                    iconName: "edit"
                    onTriggered: entryList.editEntry(model);
                }]
        }
        EntryListContent {
            id: content
            anchors.fill: parent
            time: Qt.formatTime(model.timeStamp,Qt.SystemLocaleShortDate);
            sugarValue: (settings.measurementUnit === "mg/dl") ? model.glucoseMeasurementMg.toFixed(0) : model.glucoseMeasurementMmol.toFixed(1)
            keValue: (diaryListModel.selectedGrams) ? model.mealCarbsGrams.toFixed(0) : model.mealCarbs.toFixed(1)
            bolus: model.bolus
            basal: (settings.diabetesTherapy) ? (model.temporaryPumpBasal).replace("/","\n") : model.basalInjection;
            note: model.note
            pointSizeBasal: (settings.diabetesTherapy) ? "medium" : "large"
            iRangeMin: settings.lowerRangeValue
            iRangeMax: settings.upperRangeValue
            colorSugarValue: setColor()

            function setColor(){
                if (parseFloat(sugarValue) < settings.lowerRangeValue && !(parseFloat(sugarValue) === 0)) return "#DD4814" //red
                else if(parseFloat(sugarValue) > settings.upperRangeValue) return "#DD4814" //red
                else if(parseFloat(sugarValue) >= settings.lowerRangeValue && parseFloat(sugarValue) <= settings.upperRangeValue) return "#38B44A" //green
                else return "white"
            }
        }
        onClicked: {
            Haptics.play();
            entryList.editEntry(model);
        }
    }
//    Scrollbar {
//        flickableItem: entryList
//        parent: entryList.parent
//    }
}
