/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import QtQuick.Layouts 1.1
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem

RowLayout {

    id: listContent
    anchors.fill: parent

    property alias time: dateRec.time
    property alias sugarValue: sugarRec.dispText
    property alias keValue: keRec.dispText
    property alias bolus: bolusRec.dispText
    property alias basal: basalRec.dispText
    property alias note: noteRec.dispText
    property alias measurementUnit: sugarRec.unit
    property alias colorSugarValue: sugarRec.color
    property string timeString
    property string pointSizeBasal
    property double iRangeMin: settings.lowerRangeValue
    property double iRangeMax: settings.upperRangeValue

    Rectangle{
        id: entryRec
        anchors.fill: parent
        ContentTimeItem{
            id: dateRec
            anchors.left: entryRec.left
            width: parent.width/6
            height: parent.height
        }

        ContentTextItem{
            id: sugarRec
            anchors.left: dateRec.right
            width: parent.width/6
            height: parent.height
            pointSizeFirstLabel: "x-large"
            unit: settings.measurementUnit
            radius: 50
            bold: true
            Behavior on color {ColorAnimation { duration: 500 }}
        }
        ContentTextItem{
            id: keRec
            anchors.left: sugarRec.right
            width: parent.width/6
            height: parent.height
            pointSizeFirstLabel: "large"
            unit: settings.carbsUnit
        }
        ContentTextItem{
            id: bolusRec
            anchors.left: keRec.right
            width: parent.width/6
            height: parent.height
            pointSizeFirstLabel: "large"
            unit: i18n.tr("Bolus")
        }
        ContentTextItem{
            id: basalRec
            anchors.left: bolusRec.right
            width: parent.width/6
            height: parent.height
            pointSizeFirstLabel: pointSizeBasal
            unit: i18n.tr("Basal")
        }
        ContentNoteItem{
            id: noteRec
            anchors.left: basalRec.right
            width: parent.width/6
            height: parent.height
            unit: i18n.tr("Note")
        }
    }
}
