/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import "../Graphics"

Page {
    id: aboutPage
    title: i18n.tr("About")
    flickable: null
    clip: true
    property string version: "0.2.0"

    Column {
        anchors.fill: parent
        anchors.topMargin: units.gu(3)
        anchors.horizontalCenter: parent.horizontalCenter
        spacing: units.gu(6)

        Column {
            width: parent.width
            spacing: units.gu(3)
            UbuntuShape {
                id: logo
                height: units.gu(20); width: height
                radius: "medium"
                source: Image {
                    source: Qt.resolvedUrl("../Graphics/diadiary_app.png")
                }
                anchors.horizontalCenter: parent.horizontalCenter
            }
            Label {
                fontSize: "x-large"
                font.weight: Font.DemiBold
                text: i18n.tr("Diabetes-Diary")
                anchors.horizontalCenter: parent.horizontalCenter
            }
            Label {
                fontSize: "large"
                text: i18n.tr("Version ") + aboutPage.version
                anchors.horizontalCenter: parent.horizontalCenter
                wrapMode: Text.WordWrap
            }
            Label {
                text: i18n.tr("(C) 2015-2016 Ronny Fuchs")
                anchors.horizontalCenter: parent.horizontalCenter
                wrapMode: Text.WordWrap
            }
        }

        Column {
            width: parent.width
            Label {
                fontSize: "small"
                text: i18n.tr("Source code available on ")
                anchors.horizontalCenter: parent.horizontalCenter
                onLinkActivated: Qt.openUrlExternally(link)
                wrapMode: Text.WordWrap
            }
            Label {
                fontSize: "small"
                text: "<a href=\"https://launchpad.net/diabetes-diary-app\">launchpad.net/diabetes-diary-app</a>"
                anchors.horizontalCenter: parent.horizontalCenter
                onLinkActivated: Qt.openUrlExternally(link)
                wrapMode: Text.WordWrap
            }
            Item {
                width: parent.width
                height: labelDon.height + units.gu(4)
                Label {
                    id: labelDon
                    fontSize: "small"
                    text: i18n.tr("You Like this App? Then please consider making a donation.")
                    anchors.centerIn: parent
                    wrapMode: Text.WordWrap
                    horizontalAlignment: Text.AlignHCenter
                }
            }
            Item {
                width: parent.width
                height: units.gu(5)
                Button {
                    anchors.centerIn: parent
                    width: units.gu(18)
                    text: i18n.tr("Donate")
                    onClicked: Qt.openUrlExternally("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=EYK5XHTGZ46CY")
                }
            }
        }
    }
}
