/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import Qt.labs.settings 1.0
import QtQuick.Layouts 1.0
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem
import Ubuntu.Components.Themes.Ambiance 1.1
import "../Components"

Page{
    id: editPumpBasalPage
    title: i18n.tr("New Entry")
    flickable: null
    clip: true
    head.actions: [
        Action {
            iconName: "ok"
            text: "Ok"
            onTriggered: {
                if(!basal) editPumpBasalPage.createBasal(name.text,rate.value,ckbActive.checked);
                else editPumpBasalPage.updateBasal(name.text,rate.value,ckbActive.checked);
                pageStack.pop();
            }
        },
        Action {
            iconName: "delete"
            text: i18n.tr("Delete")
            visible: (basal) ? true :false
            onTriggered: {
                editPumpBasalPage.removeBasal();
                pageStack.pop();
            }
        },
        Action {
            iconSource: Qt.resolvedUrl("../Graphics/shift.svg")
            visible: (basal) ? true :false
            text: i18n.tr("Move")
            onTriggered: {
                var component = Qt.createComponent(Qt.resolvedUrl("./ShiftDialog.qml"));
                var popup = component.createObject(editPumpBasalPage);
                popup.acceptClicked.connect(function(percent){
                    for (var i = 0; i< rate.value.length; i++){
                        rate.value[i] = rate.value[i]* percent/100;
                        rate.max = Math.max(rate.max,rate.value[i] + stepSize*2);
                    }
                    setGraph();
                });
            }
        },
        Action {
            iconName: "edit-copy"
            visible: (basal) ? true :false
            text: i18n.tr("Copy")
            onTriggered: {
                editPumpBasalPage.copyBasal(name.text,rate.value,ckbActive.checked);
                pageStack.pop();
            }
        }
    ]
    head.backAction: Action {
        iconName: "back"
        onTriggered: {
            pageStack.pop();
        }
    }
    property real stepSize: settings.stepSize
    property var basal: null

    signal updateBasal(var title, var rate, var act);
    signal createBasal(var title, var rate, var act);
    signal copyBasal(var title, var rate);
    signal removeBasal();

    function setGraph(){
        plot.model = rate.value;
        plot.maxValue = rate.max;
    }

    Settings{
        id: settings
        category: "pump-basal-settings"
        property real stepSize: 0.1
    }

    Object{
        id: cursor
        property int x: 0
        onXChanged: plot.cursor = cursor;
    }
    Object{
        id: rate
        property var value: []
        property string dbRate: (basal) ? basal.basal : ""
        property real max: 1
        onMaxChanged: plot.maxValue = max;
    }

    Component.onCompleted: {
        if (rate.dbRate === "")
            for(var i=0; i < 24; i++) rate.value.push(0);
        else{
             var parts = rate.dbRate.split(',');
             for (var j=0; j < parts.length; j++) {
                 rate.value.push(parseFloat(parts[j]));
                 rate.max = Math.max(rate.max,rate.value[j] + stepSize*2);
             }
        }
    }

    Flickable {
     id: flickable
     clip: true
     anchors.fill: parent
     contentHeight: rootCol.height
     flickableDirection: Flickable.VerticalFlick
     Column {
         id: rootCol
         width: parent.width
         spacing: units.gu(1)
         ListItem.ThinDivider{}
         TextField {
             id: name
             width: parent.width
             height: units.gu(4.5)
             font.pixelSize: units.gu(3)
             text: (basal) ? basal.name : i18n.tr("Standard")
             style: TextFieldStyle {
                 background: null
             }
         }
         ListItem.ThinDivider{}
         RowLayout {
             width: flickable.width;
             spacing: units.gu(2)
             TextField {
                 id: txtAct
                 activeFocusOnPress: false
                 selectByMouse: false
                 Layout.fillWidth: true
                 horizontalAlignment: TextInput.AlignRight
                 text: i18n.tr("Active")
                 style: TextFieldStyle {
                     background: null
                 }
             }
             CheckBox {
                 id: ckbActive
                 anchors.left: txtAct.right;
                 checked: (basal) ? basal.active : false
             }
         }
         PumpBasalPlotItem{
             id: plot
             width: flickable.width
             height: flickable.height/3
             cursor: cursor
             model: rate.value
             maxValue: rate.max
         }
         Row{
             id: buttonRow
             anchors{
                 top: plot.Bottom
                 horizontalCenter: parent.horizontalCenter
             }
             spacing: units.gu(1)
             Button{
                 id: previous
                 height: up.height*2
                 Icon{
                     width: units.gu(4)
                     height: width
                     anchors.verticalCenter: parent.verticalCenter
                     anchors.horizontalCenter: parent.horizontalCenter
                     name: "go-previous"
                     color: UbuntuColors.coolGrey
                 }
                 onClicked: cursor.x = Math.max(cursor.x - 1,0);
             }
             Column{
                 Button{
                     id: up
                     Icon{
                         width: units.gu(4)
                         height: width
                         anchors.verticalCenter: parent.verticalCenter
                         anchors.horizontalCenter: parent.horizontalCenter
                         name: "go-up"
                         color: UbuntuColors.coolGrey
                     }
                     onClicked: {
                         rate.value[cursor.x] = rate.value[cursor.x] + stepSize;
                         rate.max = Math.max(rate.max,rate.value[cursor.x]);
                         plot.model = rate.value;
                     }
                 }
                 Button{
                     id: down
                     Icon{
                         width: units.gu(4)
                         height: width
                         anchors.verticalCenter: parent.verticalCenter
                         anchors.horizontalCenter: parent.horizontalCenter
                         name: "go-down"
                         color: UbuntuColors.coolGrey
                     }
                     onClicked: {
                         rate.value[cursor.x] = Math.max(rate.value[cursor.x] - stepSize, 0);
                         rate.max = Math.max(rate.max,rate.value[cursor.x]);
                         plot.model = rate.value;
                     }
                 }
             }
             Button{
                 id: next
                 height: up.height*2
                 Icon{
                     width: units.gu(4)
                     height: width
                     anchors.verticalCenter: parent.verticalCenter
                     anchors.horizontalCenter: parent.horizontalCenter
                     name: "go-next"
                     color: UbuntuColors.coolGrey
                 }
                 onClicked: cursor.x = Math.min(cursor.x + 1,23);
             }
         }

         ListItem.Expandable {
             id: sizeExpand
             expandedHeight: sizeCol.height
             collapseOnClick: true
             anchors {
                 left: parent.left;
                 right: parent.right;
                 margins: -units.gu(2)
             }
             Column{
                 id: sizeCol
                 anchors {left: parent.left; right: parent.right;}
                 Item{
                     anchors {
                         left: parent.left;
                         right: parent.right
                     }
                     height: sizeExpand.collapsedHeight
                     ListItem.ThinDivider{}
                     ListItem.Subtitled {
                         text: i18n.tr("Step size")
                         selected: false
                         onClicked: sizeExpand.expanded = !sizeExpand.expanded
                         subText: settings.stepSize + " U"
                         Icon {
                             width: units.gu(2)
                             height: width
                             anchors.right: parent.right
                             anchors.verticalCenter: parent.verticalCenter
                             name: "go-down"
                             color: UbuntuColors.coolGrey
                         }
                     }
                 }
                 ListItem.Standard {
                     text: "0.01 U"
                     highlightWhenPressed: true
                     selected: (settings.stepSize === 0.01) ? true : false
                     onClicked: {
                         settings.stepSize = 0.01;
                         sizeExpand.expanded = false
                     }
                 }
                 ListItem.Standard {
                     text: "0.05 U"
                     selected: (settings.stepSize === 0.05) ? true : false
                     highlightWhenPressed: true
                     onClicked: {
                         settings.stepSize = 0.05;
                         sizeExpand.expanded = false
                     }
                 }
                 ListItem.Standard {
                     text: "0.10 U"
                     selected: (settings.stepSize === 0.10) ? true : false
                     highlightWhenPressed: true
                     onClicked: {
                         settings.stepSize = 0.10;
                         sizeExpand.expanded = false
                     }
                 }
             }
         }
     }
    }
}

