/*
 * Copyright (C) 2016, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem
import "../Graphics"

Page {
    id: helpPage
    title: i18n.tr("Help")
    flickable: null
    clip: true

    Flickable {
        id: flickable
        flickableDirection: Flickable.VerticalFlick
        anchors.fill: helpPage
        contentHeight: colhelp.height
        anchors.margins: units.gu(2)
        anchors.topMargin: units.gu(2)
        boundsBehavior: Flickable.StopAtBounds

        Column {
            id: colhelp
            width: parent.width
            Label{
                width: parent.width
                wrapMode: Text.Wrap
                font.weight: Font.DemiBold
                anchors.horizontalCenter: parent.horizontalCenter
                text: i18n.tr("Delete temporary basal rate")
                fontSize: "large"
            }
            ListItem.ThinDivider{}
            Label{
                width: parent.width
                wrapMode: Text.Wrap
                anchors.horizontalCenter: parent.horizontalCenter
                text: i18n.tr("Press and hold the entry.")
            }
            Image {
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width - units.gu(8)
                source: Qt.resolvedUrl("../Graphics/clearTempBasal.png")
                fillMode: Image.PreserveAspectFit
            }

            Label{
                width: parent.width
                wrapMode: Text.Wrap
                font.weight: Font.DemiBold
                anchors.horizontalCenter: parent.horizontalCenter
                text: "csv-Import"
                fontSize: "large"
            }
            ListItem.ThinDivider{}
            spacing: units.gu(1)
            Label{
                width: parent.width
                wrapMode: Text.Wrap
                anchors.horizontalCenter: parent.horizontalCenter
                text: i18n.tr("You can import diary entries using a csv-file. The csv file requires a specific format so the import is working correctly. All entries are in quotes and separated by a comma.")
            }
            Label{
                width: parent.width
                wrapMode: Text.Wrap
                text: "For example:"
            }
            Label{
                //width: parent.width
                wrapMode: Text.Wrap
                anchors.horizontalCenter: parent.horizontalCenter
                font.weight: Font.DemiBold
                text: "\"Date\",\"Time\",\"Blood glucose (mg/dl)\""
            }

            Label{
                height: units.gu(5)
                width: parent.width
                wrapMode: Text.Wrap
                font.weight: Font.DemiBold
                anchors.horizontalCenter: parent.horizontalCenter
                verticalAlignment: Text.AlignBottom
                text: "csv-Export"
                fontSize: "large"
            }
            ListItem.ThinDivider{}
            Label{
                width: parent.width
                wrapMode: Text.Wrap
                anchors.horizontalCenter: parent.horizontalCenter
                text: i18n.tr("The csv export can be saved in the Documents folder, if you share it with the document viewer.")
            }

        }

    }
}
