/*
 * Copyright (C) 2016, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import QtQuick.Layouts 1.1
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem
import Diabetes_Diary_App 1.0

Page{
    id: importResultPage
    title: i18n.tr("%1 imported entries").arg(numberOfImports)
    head.actions: Action {
            iconName: "ok"
            enabled: imports.success
            onTriggered: {
                if(!dialog){
                    dialog = PopupUtils.open(progessDialog,importResultPage);
                    imports.startImport();
                }
               selectedDB = -1;
               numberOfImports = 0;
            }
        }
    head.backAction: Action {
           iconName: "back"
           onTriggered: {
               pageStack.pop();
               selectedDB = -1;
               numberOfImports = 0;
           }
       }
    property int numberOfImports: imports.count
    property int selectedDB: -1
    property string fileName
    property bool importSuccess: false
    property var dialog: null

    Component.onCompleted: {
        if (selectedDB !== -1) {
            fileName = fileName.replace("file://","");
            imports.importFromCsv(fileName, selectedDB, diaryListModel.convValueMealCarbs);
        }
    }
    ImportModel{
        id: imports
        onImportProgress: dialog.percent = importedCount / imports.count;
        onImportingFinished: {
           PopupUtils.close(dialog)
           pageStack.pop();
           diaryListModel.acceptImportedModel();

        }
        onImportingStarted:{
            if(!dialog){
                dialog = PopupUtils.open(progessDialog,importResultPage);
            }
        }
        onError: mainView.showError(errorString);
    }
    Component{
        id: progessDialog
        Dialog{
            id: dialog
            title: i18n.tr("Import")
            property alias percent: bar.value
            contents: [
                ProgressBar {
                   id: bar
                   minimumValue: 0
                   maximumValue: 1
                }
            ]
        }
    }
    ListView{
        id: importList
        clip: true
        anchors { left: parent.left; right: parent.right;}
        height: parent.height - y
        maximumFlickVelocity: height * 4
        flickDeceleration: height
        cacheBuffer: 3000
        model: imports

        section.property: "date"
        section.criteria: ViewSection.FullString
        section.delegate: ListItem.Empty{
                height: units.dp(45)
                highlightWhenPressed: false
                RowLayout {
                    anchors {
                        left: parent.left;
                        right: parent.right;
                        verticalCenter: parent.verticalCenter;
                        margins: units.gu(1)
                    }
                    Label {
                        text: section
                        font.bold: true
                        Layout.fillWidth: true
                    }
                }
        }
        delegate: Item{
            id: items
            height: units.dp(55)
            width: parent.width
            focus: true

            ImportListViewContent {
                id: content
                anchors.fill: parent

                time: Qt.formatTime(model.timeStamp,Qt.SystemLocaleShortDate);
                sugarValue: (settings.measurementUnit === "mg/dl") ? model.glucoseMeasurementMg.toFixed(0) : model.glucoseMeasurementMmol.toFixed(1)
                keValue: (diaryListModel.selectedGrams) ? model.mealCarbsGrams.toFixed(0) : model.mealCarbs.toFixed(1)
                bolus: model.bolus
                basal: (settings.diabetesTherapy) ? (model.temporaryPumpBasal).replace("/","\n") : model.basalInjection;
                note: model.note
                pointSizeBasal: (settings.diabetesTherapy) ? "medium" : "large"
            }
        }
        Scrollbar {
            flickableItem: parent
        }
    }
}
