/*
 * Copyright (C) 2016, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem
import Diabetes_Diary_App 1.0
import "../Components"


Page{
    id: pumpBasalPage
    title: i18n.tr("Pump basal rate")
    head.actions: Action {
            iconName: "add"
            onTriggered: {
                var page = pageStack.push(Qt.createComponent(Qt.resolvedUrl("./EditPumpBasalPage.qml")));
                page.createBasal.connect(function(title,rate,act){
                        basalModel.createBasal(title,rate.toString(),act);
                });
            }
        }
    property bool footerActive: basalModel.bCanFetchMore

    function showEditPage(basal,index){
        var page = pageStack.push(Qt.createComponent(Qt.resolvedUrl("./EditPumpBasalPage.qml")),
                                  {title: i18n.tr("Edit Entry"),
                                   basal: basal});
        page.updateBasal.connect(function(title,rate,act){
            basalModel.updateBasal(basal.id,title,rate.toString(),act);
        });
        page.removeBasal.connect(function(){
            basalModel.removeBasal(basal.id);
        });
        page.copyBasal.connect(function(title,rate){
            basalModel.copyBasal(title,rate.toString());
        });
    }
    SortFilterModel{
        id: basalSortModel
        model: PumpBasalModel{
            id: basalModel
        }
        sort.property: "name"
        sort.order: Qt.AscendingOrder
        sortCaseSensitivity: Qt.CaseInsensitive

    }


    PumpBasalList{
        id: list
        anchors {left: parent.left; right: parent.right;}
        height: parent.height - y
        maximumFlickVelocity: height * 4
        flickDeceleration: height
        cacheBuffer: 3000
        model: basalSortModel
        clip: true
        footer: Loader {
            width: parent.width
            active: footerActive
            sourceComponent: ListItem.Standard{
                id: fetchMore
                text: i18n.tr("Load more...")
                onClicked: {
                    basalModel.reloadAndFetchMore();
                    footerActive = basalModel.bCanFetchMore;
                }
            }
        }
        onEditRate: showEditPage(basal,index);
    }
    EmptyState{
        iconName: "dialog-warning-symbolic"
        title: i18n.tr("No entries!")
        subTitle: i18n.tr("Click on the + symbol to add an entry!")
        anchors.centerIn: parent
        visible: (basalModel.count === 0) ? true : false
    }
}
