/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import Ubuntu.Components 1.3

Item {
    id: pumpBasalPlotItem

    property var cursor
    property var model
    property alias maxValue: canvas.max
    property bool cursorEnabled: true
    property real sum: 0

    onCursorChanged: canvas.requestPaint();
    onModelChanged: canvas.requestPaint();
    Canvas{
        id: canvas
        anchors.fill: parent

        property int leftMargins: units.gu(4)
        property int rightMargins: units.gu(1)
        property int topMargins: units.gu(4)
        property int bottomMargins: units.gu(6)

        property int contentWidth: canvas.width - leftMargins - rightMargins
        property int contentHeight: canvas.height - topMargins - bottomMargins

        property real max

        onPaint: {
            var ctx = canvas.getContext('2d');
            ctx.save();
            ctx.reset();

            ctx.translate(leftMargins,topMargins);
            ctx.font = "" + units.gu(1.5) + "px Ubuntu";

            paintAxis(ctx);
            paintGrid(ctx);
            if (pumpBasalPlotItem.cursorEnabled) paintCursor(ctx);
            paintRate(ctx);
            paintSum(ctx);
            ctx.restore();
        }
        function paintAxis(ctx){
            ctx.beginPath();
            ctx.strokeStyle = "black";
            ctx.fillStyle = "black";
            ctx.lineWidth = units.dp(1);
            ctx.beginPath();
            ctx.rect(0, 0, contentWidth, contentHeight)
            ctx.stroke();
            ctx.closePath();

            ctx.beginPath()
            var xLabel = i18n.tr("Time");
            ctx.text(xLabel,contentWidth/2 - ctx.measureText(xLabel).width, contentHeight + units.gu(4))
            ctx.fill();
            ctx.closePath();

        }

        function paintGrid(ctx){
            var dy = contentHeight / 100;
            for (var i=1; i < 24; i++){
                var yPos1 = contentHeight;
                var yPos2 = contentHeight - dy;
                for (var j = 0; j < 50; j++){
                    ctx.beginPath();
                    ctx.strokeStyle = "black";
                    ctx.fillStyle = "black";
                    ctx.lineWidth = units.dp(0.1);
                    ctx.moveTo(i * contentWidth/24, yPos1)
                    ctx.lineTo(i * contentWidth/24, yPos2)
                    ctx.stroke();
                    ctx.closePath();
                    yPos1 = yPos2 - dy;
                    yPos2 = yPos1 - dy;
                }
            }
            ctx.beginPath();
            ctx.strokeStyle = "black";
            ctx.fillStyle = "black";
            var yLabel = max.toFixed(2);
            ctx.text(yLabel, -ctx.measureText(yLabel).width - units.gu(.5), 0 + units.gu(.5));
            yLabel = (max/2).toFixed(2);
            ctx.text(yLabel, -ctx.measureText(yLabel).width - units.gu(.5), yLabel*contentHeight / max + units.gu(.5))
            ctx.text(6, 6 * contentWidth/24 - ctx.measureText(6).width/2, contentHeight + units.gu(1.5));
            ctx.text(12, 12 * contentWidth/24 - ctx.measureText(12).width/2, contentHeight + units.gu(1.5));
            ctx.text(18, 18 * contentWidth/24 - ctx.measureText(18).width/2, contentHeight + units.gu(1.5));
            ctx.fill();
            ctx.closePath();
        }


        function paintCursor(ctx){
            ctx.beginPath();
            ctx.globalAlpha = 1;
            ctx.strokeStyle = "black";
            ctx.fillStyle = "black";
            ctx.lineWidth = units.dp(1);
            ctx.moveTo(pumpBasalPlotItem.cursor.x * contentWidth/24, 0);
            ctx.lineTo(pumpBasalPlotItem.cursor.x * contentWidth/24, contentHeight);
            ctx.text(pumpBasalPlotItem.cursor.x,
                     pumpBasalPlotItem.cursor.x * contentWidth/24 - ctx.measureText(pumpBasalPlotItem.cursor.x).width/2,
                     contentHeight + units.gu(1.5))
            var yLabel = model[pumpBasalPlotItem.cursor.x].toFixed(2);
            ctx.text(yLabel,
                     -ctx.measureText(yLabel).width - units.gu(.5),
                     contentHeight - model[pumpBasalPlotItem.cursor.x] * contentHeight / max + units.gu(.5))
            ctx.stroke();
            ctx.closePath();
        }

        function paintRate(ctx){
            if (model === null) {
                for (var i = 0; i < 24; i++) model.push(0);
            }
            ctx.lineWidth = units.dp(2);
            for (var xPos = 0; xPos < 24; xPos++){
                ctx.beginPath();
                ctx.lineWidth = units.dp(2);
                ctx.strokeStyle = "red"
                ctx.fillStyle = "red"
                ctx.moveTo(xPos * contentWidth/24, contentHeight - model[xPos] * contentHeight / max);
                ctx.lineTo((xPos + 1) * contentWidth/24, contentHeight - model[xPos] * contentHeight / max);
                ctx.lineTo((xPos + 1) * contentWidth/24, contentHeight - model[xPos+1] * contentHeight / max);
                ctx.stroke();
                ctx.closePath();
            }
        }
        function paintSum(ctx){
            sum = 0;
            for(var i=0;i < 24;i++){
                sum += parseFloat(model[i]);
            }
            var sumLabel = i18n.tr("Sum: ") + sum.toFixed(2) + "U";
            ctx.beginPath();
            ctx.strokeStyle = "black";
            ctx.fillStyle = "black";
            ctx.text(sumLabel,contentWidth - ctx.measureText(sumLabel).width, - units.gu(1.5));
            ctx.fill();
            ctx.closePath();
        }
    }
}

