/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem
import Ubuntu.Content 1.1
import "../Components"

Page {
    id: settingsPage
    title: i18n.tr("Settings")
    head.sections.model: [i18n.tr("Therapy"), i18n.tr("Database"), i18n.tr("Information")]
    flickable: null

    property url filePath
    property int selectDB: -1

    function updateItems(){
        itemTherapy.updateItems();
    }

    VisualItemModel {
        id: itemModel
        SettingTherapyItem{
            id: itemTherapy
            width: itemView.width
            height: itemView.height
            onPumpBasalClicked: pageStack.push(Qt.resolvedUrl("./PumpBasalPage.qml"));
        }
        SettingDatabaseItem{
            id: itemDatabase
            width: itemView.width
            height: itemView.height
            onExportClicked: {
                var component = Qt.createComponent(Qt.resolvedUrl("./Exports/ExportDialog.qml"));
                var popup = component.createObject(settingsPage);
                popup.acceptClicked.connect(function(selectedOption){
                    if (selectedOption === "0"){
                        filePath = diaryListModel.exportToCsv();
                        pageStack.push(Qt.resolvedUrl("./Exports/SharePage.qml"), { fileUrl: filePath})
                    }
                });
            }
            onDeleteClicked: {
                var component = Qt.createComponent(Qt.resolvedUrl("./DeleteDatabaseDialog.qml"));
                var popup = component.createObject(settingsPage);
                popup.acceptClicked.connect(function(){
                    diaryListModel.deleteDataBase();
                });
            }
            onImportClicked:{
                var importDialog = Qt.createComponent(Qt.resolvedUrl("./Imports/ImportDialog.qml"));
                var popupDialog = importDialog.createObject(settingsPage);
                popupDialog.acceptClicked.connect(function(selectedOption){
                    settingsPage.selectDB = selectedOption;
                    var component = Qt.createComponent(Qt.resolvedUrl("./Imports/DatabaseImport.qml"));
                    var popup = component.createObject(settingsPage);
                    popup.selecetedDone.connect(function(selectedUrl){
                        pageStack.push(Qt.resolvedUrl("./Imports/ImportResultPage.qml"),{
                                                        selectedDB: settingsPage.selectDB,
                                                        fileName: selectedUrl})
                    });

                    //Desktop
                    //var file = "/home/ronny/Dokumente/Diabetes_Diary_export_2016_01_26.csv";
//                    var file = "/home/ronny/Dokumente/mysugr_data_2016-01-26_2148.csv";
//                    var page=pageStack.push(Qt.resolvedUrl("./Imports/ImportResultPage.qml"),{
//                                                    selectedDB: selectedOption,
//                                                    fileName: file});
                });
            }
        }

        Item{
            id: itemAbout
            width: itemView.width
            height: itemView.height
            Flickable {
                id: flickable
                clip: true
                anchors.fill: parent
                contentHeight: columnEinst.height
                boundsBehavior: Flickable.StopAtBounds
                Column {
                    id: columnEinst
                    width: parent.width

                    ListItem.Standard {
                        text: i18n.tr("Help")
                        progression: true
                        onClicked: pageStack.push(Qt.resolvedUrl("./HelpPage.qml"));
                    }
                    ListItem.Standard {
                        text: i18n.tr("About")
                        progression: true
                        onClicked: pageStack.push(Qt.resolvedUrl("./AboutPage.qml"));
                    }
                }
            }
        }
    }
    ListView {
        id: itemView
        model: itemModel
        interactive: false
        anchors.fill: parent
        orientation: Qt.Horizontal
        currentIndex: settingsPage.head.sections.selectedIndex
        snapMode: ListView.SnapOneItem
        highlightMoveDuration: UbuntuAnimation.SlowDuration
    }
}
