/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem

Item {
    id: settingsTherapyItem

    property int convCarbsValue

    signal pumpBasalClicked()

    function updateItems(){
        var lowerVal = settings.lowerRangeValue.toFixed(settings.fixpoint);
        var upperVal = settings.upperRangeValue.toFixed(settings.fixpoint);
        buttonRange.subText = i18n.tr("Lower: ") + lowerVal + " " + settings.measurementUnit + "   " +
                              i18n.tr("Upper: ") + upperVal + " " + settings.measurementUnit;
    }

    function updateMealCarbsToGrams(){
        var updateDialog = Qt.createComponent(Qt.resolvedUrl("./UpdateMealCarbsDialog.qml"));
        var popupDialog = updateDialog.createObject(settingsTherapyItem);
        popupDialog.acceptClicked.connect(function(convValue){
            convCarbsValue = convValue;
            if(diaryListModel.convValueMealCarbs !== convCarbsValue) {
                diaryListModel.convValueMealCarbs = convCarbsValue;
                diaryListModel.convAllMealCarbs();
            }
            settings.carbsUnit = "g";
        });
    }

    Flickable {
        id: flickable
        clip: true
        anchors.fill: parent
        contentHeight: columnEinst.height
        boundsBehavior: Flickable.StopAtBounds
        Column {
            id: columnEinst
            width: parent.width
            ListItem.Expandable {
                id:therapyExpand
                expandedHeight: therapyCol.height
                anchors {
                    left: parent.left;
                    right: parent.right;
                    margins: -units.gu(2)
                }
                Column{
                    id: therapyCol
                    anchors {left: parent.left;right: parent.right;}
                    Item{
                        anchors {left: parent.left;right: parent.right;}
                        height: therapyExpand.collapsedHeight
                        ListItem.Subtitled {
                            text: i18n.tr("Therapy")
                            selected: false
                            onClicked: therapyExpand.expanded = !therapyExpand.expanded
                            subText: (settings.diabetesTherapy) ? i18n.tr("Insulin pump") : i18n.tr("Insulin pen")
                            Icon {
                                width: units.gu(2)
                                height: width
                                anchors.right: parent.right
                                anchors.verticalCenter: parent.verticalCenter
                                name: "go-down"
                                color:  UbuntuColors.coolGrey
                            }
                        }
                    }
                    ListItem.Standard {
                        text: i18n.tr("Insulin pen")
                        highlightWhenPressed: true
                        selected: !settings.diabetesTherapy
                        onClicked: {
                            settings.diabetesTherapy = 0;
                            therapyExpand.expanded = false
                        }
                    }
                    ListItem.Standard {
                        text: i18n.tr("Insulin pump")
                        highlightWhenPressed: true
                        selected: settings.diabetesTherapy
                        onClicked: {
                            settings.diabetesTherapy = 1;
                            therapyExpand.expanded = false
                        }
                    }
                }
            }
            ListItem.Expandable {
                id:unitExpand
                expandedHeight: unitCol.height
                anchors {
                    left: parent.left;
                    right: parent.right;
                    margins: -units.gu(2)
                }
                Column{
                    id: unitCol
                    anchors {left: parent.left;right: parent.right;}
                    Item{
                        anchors {left: parent.left;right: parent.right}
                        height: unitExpand.collapsedHeight
                        ListItem.Subtitled {
                            text: i18n.tr("Blood sugar unit")
                            selected: false
                            onClicked: unitExpand.expanded = !unitExpand.expanded
                            subText: settings.measurementUnit
                            Icon {
                                width: units.gu(2)
                                height: width
                                anchors.right: parent.right
                                anchors.verticalCenter: parent.verticalCenter
                                name: "go-down"
                                color: UbuntuColors.coolGrey
                            }
                        }
                    }
                    ListItem.Standard {
                        text: "mg/dl"
                        highlightWhenPressed: true
                        selected: (settings.measurementUnit === text) ? true : false
                        onClicked: {
                            settings.measurementUnit = text;
                            unitExpand.expanded = false
                            settingsTherapyItem.updateItems();
                        }
                    }
                    ListItem.Standard {
                        text: "mmol/l"
                        highlightWhenPressed: true
                        selected: (settings.measurementUnit === text) ? true : false
                        onClicked: {
                            settings.measurementUnit = text;
                            unitExpand.expanded = false
                            settingsTherapyItem.updateItems();
                        }
                    }
                }
            }
            ListItem.Expandable {
                id:carbExpand
                expandedHeight: carbCol.height
                collapseOnClick: true
                anchors {
                    left: parent.left;
                    right: parent.right;
                    margins: -units.gu(2)
                }
                Column{
                    id: carbCol
                    anchors {left: parent.left;right: parent.right}
                    Item{
                        anchors {left: parent.left;right: parent.right}
                        height: carbExpand.collapsedHeight
                        ListItem.Subtitled {
                            text: i18n.tr("Carbs Inputs")
                            selected: false
                            onClicked: carbExpand.expanded = !carbExpand.expanded
                            subText: (settings.carbsUnit === "g") ? i18n.tr("Gram") : settings.carbsUnit
                            Icon {
                                width: units.gu(2)
                                height: width
                                anchors.right: parent.right
                                anchors.verticalCenter: parent.verticalCenter
                                name: "go-down"
                                color: UbuntuColors.coolGrey
                            }
                        }
                    }
                    ListItem.Standard {
                        text: "BE"
                        highlightWhenPressed: true
                        selected: (settings.carbsUnit === text) ? true : false
                        onClicked: {
                            settings.carbsUnit = text;
                            carbExpand.expanded = false
                        }
                    }
                    ListItem.Standard {
                        text: "KE"
                        selected: (settings.carbsUnit === text) ? true : false
                        highlightWhenPressed: true
                        onClicked: {
                            settings.carbsUnit = text;
                            carbExpand.expanded = false
                        }
                    }
                    ListItem.Standard {
                        text: i18n.tr("Gram")
                        selected: (settings.carbsUnit === "g") ? true : false
                        highlightWhenPressed: true
                        onClicked: {
                            if (settings.carbsUnit !== "g") updateMealCarbsToGrams();
                            carbExpand.expanded = false
                        }
                    }
                }
            }
            ListItem.Subtitled {
                id:buttonRange
                text: i18n.tr("Blood glucose range")
                onClicked: {
                    shadow.opacity = 1;
                    var popover = PopupUtils.open(Qt.resolvedUrl("../Popover/BloodGlucoseRangePopover.qml"),buttonRange);
                    popover.closed.connect(function(){
                        shadow.opacity = 0;
                    });
                }
                subText: {i18n.tr("Lower: ") + settings.lowerRangeValue.toFixed(settings.fixpoint) +" "+ settings.measurementUnit + "   " +
                    i18n.tr("Upper: ") + settings.upperRangeValue.toFixed(settings.fixpoint) +" "+ settings.measurementUnit}
            }
            ListItem.Standard {
                text: i18n.tr("Pump basal rate")
                progression: true
                visible: settings.diabetesTherapy
                onClicked: settingsTherapyItem.pumpBasalClicked();
            }
        }

    }
    Rectangle {
        id: shadow
        anchors.fill: parent
        opacity: 0.0
        gradient: Gradient {
            GradientStop { position: 1; color: "transparent" }
            GradientStop { position: 1; color: Qt.rgba(0, 0, 0, 0.2) }
        }
    }
}

