/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem
import Ubuntu.Components.Popups 1.3
import Diabetes_Diary_App 1.0
import "../utils.js" as Utils
import "../Components"

Page {
    id: statisticPage
    title: i18n.tr("Statistic")
    head.sections.model: (bShowStat) ? [i18n.tr("Measurement"), i18n.tr("Insulin"), i18n.tr("Carbs")] : null
    head.sections.enabled: bShowStat

    property bool bShowStat: (statistics.numberOfEntries >= 5) ? true : false

    function refreshStatistics(){
        statistics.measurementUnit = settings.measurementUnit;
        statistics.diabetesTherapy = settings.diabetesTherapy;
        statistics.setStatistics();
        statistics.measurementOutsideRefresh(settings.lowerRangeValue,settings.upperRangeValue);
    }

    DiaryStatistics{
        id: statistics
    }

    VisualItemModel {
        id: itemModel

        Item{
            id: measurement
            width: itemView.width
            height: itemView.height
            Flickable {
                anchors.fill: parent
                contentHeight: colStat.height
                boundsBehavior: Flickable.StopAtBounds
                clip: true
                Column {
                    id: colStat
                    width: parent.width
                    ListItem.SingleValue {
                        text: i18n.tr("Number of measured data");
                        value: statistics.numberOfEntries;
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Average of last week");
                        value: statistics.measurementAverageWeek.toFixed(settings.fixpoint) + " " + settings.measurementUnit;
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Average of last month");
                        value: statistics.measurementAverageMonth.toFixed(settings.fixpoint) + " " + settings.measurementUnit;
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Average of last quarter")
                        value: statistics.measurementAverageQuarter.toFixed(settings.fixpoint) + " " + settings.measurementUnit;
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Estimated HbA1c");
                        value: statistics.hba1c.toFixed(1) + " %";
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Measured data out of range");
                        value: statistics.measurementOutside.toFixed(0) + " %";
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Measured data below the range");
                        value: statistics.measurementBelow.toFixed(0) + " %";
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Measured data above the range");
                        value: statistics.measurementAbove.toFixed(0) + " %";
                    }
                }
            }
        }
        Item{
            id: insulin
            width: itemView.width
            height: itemView.height
            Flickable {
                anchors.fill: parent
                boundsBehavior: Flickable.StopAtBounds
                contentHeight: colins.height
                clip: true
                Column {
                    id: colins
                    width: parent.width
                    ListItem.SingleValue {
                        text: i18n.tr("Ratio Bolus/Basal");
                        value: (settings.diabetesTherapy) ? "n.a." : statistics.bolusRatio.toFixed(0) + "% / " + statistics.basalRatio.toFixed(0) + "%";
                        visible: !settings.diabetesTherapy;
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Average of last week");
                        value: statistics.insulinAverageWeek.toFixed(1) + i18n.tr(" iU/day");
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Average of last month");
                        value: statistics.insulinAverageMonth.toFixed(1) + i18n.tr(" iU/day");
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Average of last quarter");
                        value: statistics.insulinAverageQuarter.toFixed(1) + i18n.tr(" iU/day");
                    }
                }//Column
            }
        }
        Item{
            id: carbs
            width: itemView.width
            height: itemView.height
            Flickable {
                anchors.fill: parent
                boundsBehavior: Flickable.StopAtBounds
                contentHeight: colcarbs.height
                clip: true
                Column {
                    id: colcarbs
                    width: parent.width
                    ListItem.SingleValue {
                        text: i18n.tr("Average of last week");
                        value: statistics.carbsAverageWeek.toFixed(1) + " " + settings.carbsUnit + "/" + i18n.tr("day");
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Average of last month");
                        value: statistics.carbsAverageMonth.toFixed(1) + " " + settings.carbsUnit + "/" + i18n.tr("day");
                    }
                    ListItem.SingleValue {
                        text: i18n.tr("Average of last quarter");
                        value: statistics.carbsAverageQuarter.toFixed(1) + " " + settings.carbsUnit + "/" + i18n.tr("day");
                    }
                }//Column
            }
        }
    }
    ListView {
        id: itemView
        model: itemModel
        visible: bShowStat
        interactive: false
        anchors.fill: parent
        orientation: Qt.Horizontal
        currentIndex: statisticPage.head.sections.selectedIndex
        snapMode: ListView.SnapOneItem
        highlightMoveDuration: UbuntuAnimation.SlowDuration
    }
    EmptyState{
        iconName: "dialog-warning-symbolic"
        title: i18n.tr("Not enough measurements!")
        subTitle: i18n.tr("There must be at least 5 blood sugar values!")
        anchors.centerIn: parent
        visible: !bShowStat
    }
}

