/*
 * Copyright (C) 2015, Ronny Fuchs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
import QtQuick 2.4
import Qt.labs.settings 1.0
import Ubuntu.Content 0.1
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import Ubuntu.Components.ListItems 1.3
import UserMetrics 0.1
import Diabetes_Diary_App 1.0
import "./Components"
import "./Diary"
import "./Settings"
import "./Statistics"

import "./utils.js" as Utils

MainView {
    id: mainView
    objectName: "Diabetes-Diary"
    applicationName: "diabetes-diary-app.fuchsi"
    width: units.gu(45); height: units.gu(71)
    theme.name: "Ubuntu.Components.Themes.Ambiance"


    property var files: null
    property var importPath
    property int selectDB
    function importCSVData(){
        console.log(files);
        console.log(files.items[0].url.toString());
        if (files == null) return;

        mainView.importPath = files.items[0].url.toString().replace("file://", "");
        var importDialog = Qt.createComponent(Qt.resolvedUrl("./Settings/Imports/ImportDialog.qml"));
        var popupDialog = importDialog.createObject(mainView);
        popupDialog.acceptClicked.connect(function(selectedOption){
            mainView.selectDB = selectedOption;
            pageStack.push(Qt.resolvedUrl("./Settings/Imports/ImportResultPage.qml"),{
                                            selectedDB: mainView.selectDB,
                                            fileName: mainView.importPath});
        });

        files = null;
    }
    function showError(message){
        PopupUtils.open(Qt.resolvedUrl("./Popover/ErrorDialog.qml"),mainView,
                        {text: message });
    }
    Connections {
        target: ContentHub
        onImportRequested: {
            files = transfer;
            importCSVData();
        }
        onShareRequested: {
            files = transfer;
            importCSVData();
        }
    }
    DiaryListModel{
        id: diaryListModel
        onCountChanged: statistikPage.refreshStatistics();
    }
    Metric{
        id: entryMetric
        name: "entry-metric"
        format: i18n.tr("Today Diabetes-Diary entries stored: ")+"<b>%1<\b>"
        emptyFormat: i18n.tr("No Diabetes-Diary entries today.")
        domain: applicationName
    }
    Settings{
        id: settings
        category: "measurement-settings"
        property string measurementUnit: "mg/dl"
        property string carbsUnit: "KE"
        property int diabetesTherapy: 0
        property int fixpoint: 0
        property real lowerRangeValue: 90
        property real lowerRangeValueMin: 60
        property real lowerRangeValueMax: 130
        property real upperRangeValue: 145
        property real upperRangeValueMin: 131
        property real upperRangeValueMax: 180

        Component.onCompleted: {
            diaryListModel.internationalUnit = fixpoint;
            statistikPage.refreshStatistics();
        }
        onCarbsUnitChanged: {
            if (carbsUnit === "g") diaryListModel.selectedGrams = true;
            else diaryListModel.selectedGrams = false;
            statistikPage.refreshStatistics();
        }

        onLowerRangeValueChanged: {
            settingPage.updateItems();
            statistikPage.refreshStatistics();
        }
        onUpperRangeValueChanged: {
            settingPage.updateItems();
            statistikPage.refreshStatistics();
        }
        onDiabetesTherapyChanged: statistikPage.refreshStatistics();
        onMeasurementUnitChanged: {
            fixpoint = !fixpoint;
            lowerRangeValue = Utils.convValues(lowerRangeValue,measurementUnit,fixpoint);
            upperRangeValue = Utils.convValues(upperRangeValue,measurementUnit,fixpoint);
            if (measurementUnit === "mg/dl"){
                lowerRangeValueMin = 60; lowerRangeValueMax = 130;
                upperRangeValueMin = 131;upperRangeValueMax = 180;
            }
            else{
                lowerRangeValueMin = 3.3; lowerRangeValueMax = 7;
                upperRangeValueMin = 7.1; upperRangeValueMax = 11;
            }
            diaryListModel.internationalUnit = fixpoint;
            statistikPage.refreshStatistics();
        }
    }
    Component.onCompleted: pageStack.push(tabs);
    PageStack {
        id: pageStack
        anchors.fill: parent
        Tabs{
            id: tabs
            anchors.fill: parent
            Tab{
                id: diaryTab
                title: i18n.tr("Diary")
                page: DiaryPage{
                    id: diaryPage
                }
            }
            Tab{
                id: statistikTab
                title: i18n.tr("Statistic")
                page: StatistikPage{
                    id: statistikPage
                }
            }
            Tab{
                id: settingTab
                title: i18n.tr("Settings")
                page: SettingPage{
                    id: settingPage
                }
            }
        }
    }
}
