#ifndef DATABASEWORKER_H
#define DATABASEWORKER_H

#include <QObject>
#include <QSqlDatabase>
#include <QSqlQuery>
#include <QSqlQueryModel>

#include "../Diary/diaryentry.h"
#include "../Settings/pumpbasal.h"

class DatabaseWorker : public QObject
{
    Q_OBJECT
public:
    ~DatabaseWorker();
    static DatabaseWorker *instance();


public slots:
    int saveEntry(DiaryEntry* entry);
    int savePumpEntry(PumpBasal* entry);
    int updateEntry(DiaryEntry* entry);
    int updatePumpEntry(PumpBasal* entry);
    int importEntry(DiaryEntry* entry);
    int databaseVersion();
    QSqlQueryModel* getAllEntries();
    QSqlQueryModel* getAllPumpRates();
    QVariant getSetting(QString setting);
    bool setSetting(QString setting, QString value);
    bool deleteAllEntries();
    bool deleteEntry(const int &id);
    bool deletePumpEntry(const int &id);
    QString exportToCsv(const bool selectCarbGram, const int convValue);
    void openDatabase();
    void closeDatabase();
    double columnSum(QString colName);

protected:

private:
    explicit DatabaseWorker(QObject *parent = 0);
    static DatabaseWorker *s_instance;
    QSqlDatabase m_db;
    QSqlQuery* m_query;
    QSqlQueryModel *m_SqlTableEntries;
    QSqlQueryModel *m_SqlTablePump;

    bool m_databaseOpen;
    int entryToDatabase(DiaryEntry* entry, const bool bUpdate, const bool bsendId);
    int pumpToDatabase(PumpBasal* entry, const bool bUpdate, const bool bsendId);
    //void openDatabase();
    void checkTables();
    void updateDatabaseV3();
};

#endif // DATABASEWORKER_H


