#include <QStandardPaths>
#include <QDir>
#include <QSqlDatabase>
#include <QSqlQuery>
#include <QSqlError>
#include <QDebug>
#include <QSqlTableModel>
#include <QObject>
#include <QSqlDatabase>

#include "../constants.h"
#include "../Diary/diaryentry.h"
#include "importworker.h"

ImportWorker::ImportWorker(const QList<DiaryEntry*> data,QObject *parent)
    : QObject(parent)
    , m_databaseOpen(false)
    , m_data(data)
{
    QDir databaseDir(QStandardPaths::standardLocations(QStandardPaths::DataLocation).first());
    QString dbName = DATABASENAME;
    if(!databaseDir.exists()){
        databaseDir.mkdir(databaseDir.absolutePath());
    }
    if(!m_db.connectionNames().contains(dbName)){
        m_db = QSqlDatabase::addDatabase("QSQLITE",dbName);
        m_db.setDatabaseName(databaseDir.absolutePath()+"/" + dbName + ".sqlite");
    }
    else{
        m_db = QSqlDatabase::database(dbName);
    }

    if (!m_db.isOpen()){
        qWarning() << "Worker: Database: " + m_db.databaseName() + " is not open!";
        if (!m_db.open()){
            qWarning() << "Worker:Error: " + m_db.lastError().text();
        } else {
            qWarning() << "Worker: Database: " + m_db.databaseName() + " opened!";
        }
    }
    query = new QSqlQuery(m_db);
    if (!query->exec(QUERY_DELETE_TABLE_ENTRIES)){
        qWarning() << "Worker: Fehler beim Löschen der DB!";
        qWarning() << query->lastError();
    }
    if (!query->exec(QUERY_CREATE_TABLE_ENTRIES)){
        qWarning() << "Worker: Fehler beim Erzeugen des Table!";
        qWarning() << query->lastError();
    }
    m_databaseOpen = m_db.isOpen();
}
ImportWorker::~ImportWorker(){
    if(m_databaseOpen){
        query->clear();
        m_db.close();
    }
}

void ImportWorker::slotExecute(){
    if(m_databaseOpen){
        for (int i=0; i < m_data.count(); i++){
            saveToDatabase(m_data.at(i));
            if ((i % 100) == 0) {
                emit progress(i);
            }
        }
    }
    emit progress(m_data.count());
    emit finished();
}
bool ImportWorker::saveToDatabase(DiaryEntry* entry){
    query->prepare(QUERY_ENTRIES_INSERT);

    query->addBindValue(entry->createdTimeStamp());
    query->addBindValue(entry->createdDate());
    query->addBindValue(entry->createdTimeStamp().toLocalTime());

    if (entry->glucMeasValueMg() != 0) query->addBindValue(entry->glucMeasValueMg());
    else query->addBindValue(SQLNULL);
    if (entry->glucMeasValueMmol() != 0) query->addBindValue(entry->glucMeasValueMmol());
    else query->addBindValue(SQLNULL);
    if (entry->mealCarbs() != 0) query->addBindValue(entry->mealCarbs());
    else query->addBindValue(SQLNULL);
    if (entry->bolus() != 0) query->addBindValue(entry->bolus());
    else query->addBindValue(SQLNULL);
    if (!entry->temporaryPumpBasal().isEmpty()) query->addBindValue(entry->temporaryPumpBasal());
    else query->addBindValue(SQLNULL);
    if (entry->basalInjection() != 0) query->addBindValue(entry->basalInjection());
    else query->addBindValue(SQLNULL);
    if (!entry->note().isEmpty()) query->addBindValue(entry->note());
    else query->addBindValue(SQLNULL);

    if (!query->exec()){
        qWarning() << query->lastError();
        return false;
    }

    return true;
}


