#ifndef ENTRY_H
#define ENTRY_H

#include <QObject>
#include <QDateTime>

class DiaryEntry : public QObject
{
    Q_OBJECT
    Q_PROPERTY(int id READ id WRITE setId NOTIFY idChanged)
    Q_PROPERTY(QDateTime createdTimeStamp READ createdTimeStamp WRITE setCreatedTimeStamp NOTIFY createdTimeStampChanged)
    Q_PROPERTY(QTime createdTime READ createdTime WRITE setCreatedTime NOTIFY createdTimeChanged)
    Q_PROPERTY(QDate createdDate READ createdDate WRITE setCreatedDate NOTIFY createdDateChanged)
    Q_PROPERTY(double glucMeasValueMg READ glucMeasValueMg WRITE setGlucMeasValueMg NOTIFY glucMeasValueMgChanged)
    Q_PROPERTY(double glucMeasValueMmol READ glucMeasValueMmol WRITE setGlucMeasValueMmol NOTIFY glucMeasValueMmolChanged)
    Q_PROPERTY(double mealCarbs READ mealCarbs WRITE setMealCarbs NOTIFY mealCarbsChanged)
    Q_PROPERTY(double mealCarbsGrams READ mealCarbsGrams WRITE setMealCarbsGrams NOTIFY mealCarbsGramsChanged)
    Q_PROPERTY(double bolus READ bolus WRITE setBolus NOTIFY bolusChanged)
    Q_PROPERTY(double basalInjection READ basalInjection WRITE setBasalInjection NOTIFY basalInjectionChanged)
    Q_PROPERTY(QString temporaryPumpBasal READ temporaryPumpBasal WRITE setTemporaryPumpBasal NOTIFY temporaryPumpBasalChanged)
    Q_PROPERTY(QString note READ note WRITE setNote NOTIFY noteChanged)

public:
    explicit DiaryEntry(QObject *parent = 0);

    int id();
    void setId(const int &value);

    QDateTime createdTimeStamp();
    void setCreatedTimeStamp(const QDateTime &timeStamp);

    QTime createdTime();
    void setCreatedTime(const QTime &time);

    QDate createdDate();
    void setCreatedDate(const QDate &date);

    double glucMeasValueMg();
    void setGlucMeasValueMg(const double &value);

    double glucMeasValueMmol();
    void setGlucMeasValueMmol(const double &value);

    double mealCarbs();
    void setMealCarbs(const double &value);

    double mealCarbsGrams();
    void setMealCarbsGrams(const double &value);

    double bolus();
    void setBolus(const double &value);

    double basalInjection();
    void setBasalInjection(const double &value);

    QString temporaryPumpBasal();
    void setTemporaryPumpBasal(const QString &value);

    QString note();
    void setNote(const QString &text);

signals:
    void idChanged();
    void createdTimeStampChanged();
    void createdTimeChanged();
    void createdDateChanged();
    void glucMeasValueMgChanged();
    void glucMeasValueMmolChanged();
    void mealCarbsChanged();
    void mealCarbsGramsChanged();
    void bolusChanged();
    void basalInjectionChanged();
    void temporaryPumpBasalChanged();
    void noteChanged();

public slots:

private:
    int m_id;
    QDateTime m_createdTimeStamp;
    QTime m_createdTime;
    QDate m_createdDate;
    double m_glucMeasValueMg;
    double m_glucMeasValueMmol;
    double m_mealCarbs;
    double m_mealCarbsGrams;
    double m_bolus;
    double m_basalInjection;
    QString m_temporaryPumpBasal;
    QString m_note;

};

#endif // ENTRY_H
