#include <QDebug>
#include <libintl.h>

#include "diarylistfiltermodel.h"

DiaryListFilterModel::DiaryListFilterModel(QObject *parent)
    : QSortFilterProxyModel(parent)
{
    setSortRole(DiaryListModel::RoleCreatedTimeStamp);
    setDynamicSortFilter(true);
    sort(0,Qt::DescendingOrder);
    setFilterCaseSensitivity(Qt::CaseInsensitive);
}
int DiaryListFilterModel::count() const{
    return rowCount();
}

bool DiaryListFilterModel::lessThan(const QModelIndex &left, const QModelIndex &right) const{
    QDateTime leftDate = sourceModel()->data(left, DiaryListModel::RoleCreatedTimeStamp).toDateTime();
    QDateTime rightDate = sourceModel()->data(right, DiaryListModel::RoleCreatedTimeStamp).toDateTime();

    if (leftDate.operator ==(rightDate)){
        int leftId = sourceModel()->data(left, DiaryListModel::RoleId).toInt();
        int rightId = sourceModel()->data(right, DiaryListModel::RoleId).toInt();

        return leftId < rightId;
    }
    return leftDate < rightDate;
}
bool DiaryListFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const{

    QModelIndex index = sourceModel()->index(sourceRow, 0, sourceParent);
    QString note = sourceModel()->data(index, DiaryListModel::RoleNote).toString();

    return note.contains(filterRegExp());
}

QString DiaryListFilterModel::sectionTitle(const QVariantMap &dateString){
    QDate sectionDate = dateString["date"].toDate();
    QDate date = QDate::currentDate();

    if (sectionDate.operator ==(date)) return gettext("Today");
    else if(sectionDate.operator ==(date.addDays(-1))) return gettext("Yesterday");
    else if(sectionDate.operator <(date.addDays(-1)) & sectionDate.operator >=(date.addDays(-6))) {
        return sectionDate.longDayName(sectionDate.dayOfWeek());
    }
    return sectionDate.toString(QLocale::system().dateFormat(QLocale::LongFormat));
}
QString DiaryListFilterModel::sectionAverage(const QVariantMap &dateString, const QString &unit){
    QDate sectionDate = dateString["date"].toDate();
    QDate dbDate;
    QString resultString;
    double modelValue = 0;
    double entryCount = 0;
    double entrySum   = 0;
    double sectionSum = 0;
    //mg/dl
    int columnIdx = 4;
    int fixpoint = 0;
    int role = DiaryListModel::RoleGlucMeasValueMg;
    if (unit.operator ==("mmol/l")){
        columnIdx = 5;
        fixpoint = 1;
        role = DiaryListModel::RoleGlucMeasValueMmol;
    }
    for (int i = 0; i < rowCount(); i++){
        dbDate = data(index(i,0),DiaryListModel::RoleCreatedDate).toDate();
        if(dbDate.operator ==(sectionDate)) {
            modelValue = data(index(i,0),role).toDouble();
            if (modelValue != 0){
                entryCount ++;
                entrySum   += modelValue;
            }
        }
    }
    if (entryCount > 0) {
        sectionSum = entrySum/entryCount;
        return QChar::fromLatin1(216) + QString::number(sectionSum,'f',fixpoint) + " " + unit;
        //m_sectionSum.append(sectionDate.toString(QLocale::system().dateFormat(QLocale::ShortFormat)),sectionSum);
    }
    return "";
}
bool DiaryListFilterModel::dateCompare(const QVariantMap &data){
    QDateTime compare = data["compare"].toDateTime();
    return QDateTime::currentDateTime().operator <(compare);
}
