#include <QStandardPaths>
#include <QSqlError>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QDate>

#include "../Settings/importmodel.h"
#include "diarylistmodel.h"
#include "../constants.h"
#include "../Database/databaseworker.h"

DiaryListModel::DiaryListModel(QObject *parent)
    : QAbstractListModel(parent)
    , m_SqlTableEntries(new QSqlQueryModel())
{
    readSqlData();
}
DiaryListModel::~DiaryListModel(){
    m_SqlTableEntries->clear();
}
void DiaryListModel::readSqlData(){
    m_SqlTableEntries    = DatabaseWorker::instance()->getAllEntries();
    m_convValueMealCarbs = DatabaseWorker::instance()->getSetting(VARNAME_SETTINGS_MEALCARBS_CONVVALUE).toInt();
    m_selectedGrams      = DatabaseWorker::instance()->getSetting(VARNAME_SETTINGS_SELECTEDMEALCARBSGRAMS).toBool();

    if (m_bCanFetchMore != m_SqlTableEntries->canFetchMore()){
        m_bCanFetchMore = m_SqlTableEntries->canFetchMore();
        Q_EMIT bCanFetchMoreChanged();
    }
    for (int rowIdx = 0; rowIdx < m_SqlTableEntries->rowCount(); rowIdx++){
        DiaryEntry *newEntry = new DiaryEntry(this);
        newEntry->setCreatedTimeStamp(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_CREATEDTIME)).toDateTime());
        newEntry->setCreatedDate(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_DATE)).toDate());
        newEntry->setCreatedTime(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_TIME)).toTime());
        newEntry->setGlucMeasValueMg(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_GLUCOSE_MG)).toDouble());
        newEntry->setGlucMeasValueMmol(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_GLUCOSE_MMOL)).toDouble());
        newEntry->setMealCarbs(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_MEALCARBS)).toDouble());
        newEntry->setMealCarbsGrams(newEntry->mealCarbs() * m_convValueMealCarbs);
        newEntry->setBolus(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_BOLUS)).toDouble());
        newEntry->setBasalInjection(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_BASALINJECT)).toDouble());
        newEntry->setTemporaryPumpBasal(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_TEMP_PUMPBASAL)).toString());
        newEntry->setNote(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_NOTE)).toString());
        newEntry->setId(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_ID)).toInt());
        beginInsertRows(QModelIndex(),m_diarylist.count(),m_diarylist.count());
        m_diarylist.append(newEntry);
        endInsertRows();
    }
    Q_EMIT countChanged();
}
void DiaryListModel::createEntry(const QVariantMap &values){
    DiaryEntry *newEntry = new DiaryEntry(this);
    newEntry->setCreatedTimeStamp(values[VARNAME_ENTRIES_DATE].toDateTime());
    newEntry->setCreatedTime(values[VARNAME_ENTRIES_DATE].toTime());
    newEntry->setCreatedDate(values[VARNAME_ENTRIES_DATE].toDate());
    if (!m_internationalUnit){
        newEntry->setGlucMeasValueMg(values[VARNAME_ENTRIES_GLUCOSE].toDouble());
        newEntry->setGlucMeasValueMmol(values[VARNAME_ENTRIES_GLUCOSE].toDouble()/MEASUREMENT_CONV_FACTOR);
    }
    else{
        newEntry->setGlucMeasValueMg(values[VARNAME_ENTRIES_GLUCOSE].toDouble()*MEASUREMENT_CONV_FACTOR);
        newEntry->setGlucMeasValueMmol(values[VARNAME_ENTRIES_GLUCOSE].toDouble());
    }
    if (!m_selectedGrams){
        newEntry->setMealCarbs(values[VARNAME_ENTRIES_MEALCARBS].toDouble());
        newEntry->setMealCarbsGrams(values[VARNAME_ENTRIES_MEALCARBS].toDouble() * m_convValueMealCarbs);
    }
    else{
        newEntry->setMealCarbs(values[VARNAME_ENTRIES_MEALCARBS].toDouble() / m_convValueMealCarbs);
        newEntry->setMealCarbsGrams(values[VARNAME_ENTRIES_MEALCARBS].toDouble());
    }
    newEntry->setBolus(values[VARNAME_ENTRIES_BOLUS].toDouble());
    newEntry->setBasalInjection(values[VARNAME_ENTRIES_BASALINJECT].toDouble());
    newEntry->setTemporaryPumpBasal(values[VARNAME_ENTRIES_TEMP_PUMPBASAL].toString());
    newEntry->setNote(values[VARNAME_ENTRIES_NOTE].toString());
    int newId = DatabaseWorker::instance()->saveEntry(newEntry);
    if(newId != -1){
        newEntry->setId(newId);
        emit beginInsertRows(QModelIndex(),m_diarylist.count(),m_diarylist.count());
        m_diarylist.append(newEntry);
        emit endInsertRows();
        Q_EMIT countChanged();
    }
}
bool DiaryListModel::deleteEntry(const int &id){
    if(DatabaseWorker::instance()->deleteEntry(id)){
        int idx = indexOfId(id);
        beginRemoveRows(QModelIndex(),idx,idx);
        m_diarylist.takeAt(idx)->deleteLater();
        endRemoveRows();
        Q_EMIT countChanged();
        return true;
    }
    return false;
}
void DiaryListModel::updateEntry(const int &id, const QVariantMap &values){
    DiaryEntry *entry = m_diarylist.value(indexOfId(id));
    entry->setCreatedTimeStamp(values[VARNAME_ENTRIES_DATE].toDateTime());
    entry->setCreatedTime(values[VARNAME_ENTRIES_DATE].toTime());
    entry->setCreatedDate(values[VARNAME_ENTRIES_DATE].toDate());
    if (!m_internationalUnit){
        entry->setGlucMeasValueMg(values[VARNAME_ENTRIES_GLUCOSE].toDouble());
        entry->setGlucMeasValueMmol(values[VARNAME_ENTRIES_GLUCOSE].toDouble() / MEASUREMENT_CONV_FACTOR);
    }
    else{
        entry->setGlucMeasValueMg(values[VARNAME_ENTRIES_GLUCOSE].toDouble() * MEASUREMENT_CONV_FACTOR);
        entry->setGlucMeasValueMmol(values[VARNAME_ENTRIES_GLUCOSE].toDouble());
    }
    if (!m_selectedGrams){
        entry->setMealCarbs(values[VARNAME_ENTRIES_MEALCARBS].toDouble());
        entry->setMealCarbsGrams(values[VARNAME_ENTRIES_MEALCARBS].toDouble() * m_convValueMealCarbs);
    }
    else{
        entry->setMealCarbs(values[VARNAME_ENTRIES_MEALCARBS].toDouble() / m_convValueMealCarbs);
        entry->setMealCarbsGrams(values[VARNAME_ENTRIES_MEALCARBS].toDouble());
    }
    entry->setBolus(values[VARNAME_ENTRIES_BOLUS].toDouble());
    entry->setBasalInjection(values[VARNAME_ENTRIES_BASALINJECT].toDouble());
    entry->setTemporaryPumpBasal(values[VARNAME_ENTRIES_TEMP_PUMPBASAL].toString());
    entry->setNote(values[VARNAME_ENTRIES_NOTE].toString());

    int res = DatabaseWorker::instance()->updateEntry(entry);
    if(res != -1){
        emit dataChanged(index(m_diarylist.indexOf(entry)), index(m_diarylist.indexOf(entry)));
    }
}
void DiaryListModel::setInternationalUnit(const quint8 &unit){
    if (m_internationalUnit != unit){
        m_internationalUnit = unit;
        Q_EMIT internationalUnitChanged();
    }
}
QString DiaryListModel::exportToCsv(){
    m_exportFile = DatabaseWorker::instance()->exportToCsv(m_selectedGrams,m_convValueMealCarbs);
    return m_exportFile;
}
quint8 DiaryListModel::internationalUnit(){
    return m_internationalUnit;
}
int DiaryListModel::rowCount(const QModelIndex &parent) const{
    Q_UNUSED(parent)
    return m_diarylist.count();
}
bool DiaryListModel::deleteDataBase(){
    if (!DatabaseWorker::instance()->deleteAllEntries()){
        qWarning() << "Fehler beim Löschen der DB!";
        return false;
    }
    else {
        emit beginRemoveRows(QModelIndex(), 0, rowCount() - 1);
        for (int i = 0; i < m_diarylist.count(); i++) {
            delete m_diarylist[i];
        }
        m_diarylist.clear();
        emit endRemoveRows();
        m_bCanFetchMore = false;
        Q_EMIT bCanFetchMoreChanged();
        Q_EMIT countChanged();
        return true;
    }
}
int DiaryListModel::indexOfId(const int &id){
    for (int i = 0; i < m_diarylist.size(); i++) {
        if (id == m_diarylist[i]->id())
            return i;
    }
    return -1;
}
QVariant DiaryListModel::data(const QModelIndex &index, int role) const{
    switch(role){
    case RoleCreatedTimeStamp:
        return m_diarylist.at(index.row())->createdTimeStamp();
    case RoleCreatedTime:
        return m_diarylist.at(index.row())->createdTime();
    case RoleCreatedDate:
        return m_diarylist.at(index.row())->createdDate();
    case RoleGlucMeasValueMg:
        return m_diarylist.at(index.row())->glucMeasValueMg();
    case RoleGlucMeasValueMmol:
        return m_diarylist.at(index.row())->glucMeasValueMmol();
    case RoleMealCarbs:
        return m_diarylist.at(index.row())->mealCarbs();
    case RoleMealCarbsGrams:
        return m_diarylist.at(index.row())->mealCarbsGrams();
    case RoleBolus:
        return m_diarylist.at(index.row())->bolus();
    case RoleBasalInjection:
        return m_diarylist.at(index.row())->basalInjection();
    case RoleTemporaryPumpBasal:
        return m_diarylist.at(index.row())->temporaryPumpBasal();
    case RoleNote:
        return m_diarylist.at(index.row())->note();
    case RoleId:
        return m_diarylist.at(index.row())->id();
    }
    return QVariant();
}
QHash<int, QByteArray> DiaryListModel::roleNames() const{
    QHash<int, QByteArray> roles;
    roles.insert(RoleCreatedTimeStamp,"timeStamp");
    roles.insert(RoleCreatedTime,"time");
    roles.insert(RoleCreatedDate,"date");
    roles.insert(RoleGlucMeasValueMg,"glucoseMeasurementMg");
    roles.insert(RoleGlucMeasValueMmol,"glucoseMeasurementMmol");
    roles.insert(RoleMealCarbs,"mealCarbs");
    roles.insert(RoleMealCarbsGrams,"mealCarbsGrams");
    roles.insert(RoleBolus,"bolus");
    roles.insert(RoleBasalInjection,"basalInjection");
    roles.insert(RoleTemporaryPumpBasal,"temporaryPumpBasal");
    roles.insert(RoleNote,"note");
    roles.insert(RoleId,"id");
    return roles;
}
bool DiaryListModel::bCanFetchMore(){
    return m_bCanFetchMore;
}
void DiaryListModel::reloadAndFetchMore(){
    if(m_bCanFetchMore){
        m_SqlTableEntries->fetchMore();
        if (m_bCanFetchMore != m_SqlTableEntries->canFetchMore()){
            m_bCanFetchMore = m_SqlTableEntries->canFetchMore();
            Q_EMIT bCanFetchMoreChanged();
        }
        for (int rowIdx = rowCount(); rowIdx < m_SqlTableEntries->rowCount(); rowIdx++){
            DiaryEntry *newEntry = new DiaryEntry(this);
            newEntry->setCreatedTimeStamp(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_CREATEDTIME)).toDateTime());
            newEntry->setCreatedDate(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_DATE)).toDate());
            newEntry->setCreatedTime(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_TIME)).toTime());
            newEntry->setGlucMeasValueMg(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_GLUCOSE_MG)).toDouble());
            newEntry->setGlucMeasValueMmol(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_GLUCOSE_MMOL)).toDouble());
            newEntry->setMealCarbs(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_MEALCARBS)).toDouble());
            newEntry->setMealCarbsGrams(newEntry->mealCarbs() * m_convValueMealCarbs);
            newEntry->setBolus(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_BOLUS)).toDouble());
            newEntry->setBasalInjection(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_BASALINJECT)).toDouble());
            newEntry->setTemporaryPumpBasal(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_TEMP_PUMPBASAL)).toString());
            newEntry->setNote(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_NOTE)).toString());
            newEntry->setId(m_SqlTableEntries->data(m_SqlTableEntries->index(rowIdx,IDX_ENTRIES_ID)).toInt());
            beginInsertRows(QModelIndex(),m_diarylist.count(),m_diarylist.count());
            m_diarylist.append(newEntry);
            endInsertRows();
        }
        Q_EMIT countChanged();
    }

}
void DiaryListModel::acceptImportedModel(){
    DatabaseWorker::instance()->openDatabase();
    m_SqlTableEntries->clear();
    m_bCanFetchMore=false;
    beginRemoveRows(QModelIndex(), 0, rowCount() - 1);
    for (int i = 0; i < m_diarylist.count(); i++) {
        delete m_diarylist[i];
    }
    m_diarylist.clear();
    endRemoveRows();

    readSqlData();
}
bool DiaryListModel::convAllMealCarbs(){
    beginResetModel();
    foreach (DiaryEntry* entry, m_diarylist) {
        if(entry->mealCarbs() != 0){
            entry->setMealCarbsGrams(entry->mealCarbs() * m_convValueMealCarbs);
        }
    }
    endResetModel();
    return true;
}

bool DiaryListModel::selectedGrams(){
    return m_selectedGrams;
}
void DiaryListModel::setSelectedGrams(const bool selectedValue){
    if(m_selectedGrams != selectedValue){
        m_selectedGrams = selectedValue;
        DatabaseWorker::instance()->setSetting(VARNAME_SETTINGS_SELECTEDMEALCARBSGRAMS,QString::number(m_selectedGrams));
        Q_EMIT selectedGramsChanged();
    }
}
quint8 DiaryListModel::convValueMealCarbs(){
    return m_convValueMealCarbs;
}
void DiaryListModel::setConvValueMealCarbs(const quint8 &value){
    if(m_convValueMealCarbs != value){
        m_convValueMealCarbs = value;
        DatabaseWorker::instance()->setSetting(VARNAME_SETTINGS_MEALCARBS_CONVVALUE,QString::number(m_convValueMealCarbs));
        Q_EMIT convValueMealCarbsChanged();
    }
}
