#ifndef DIARYLISTMODEL_H
#define DIARYLISTMODEL_H

#include <QDebug>
#include <QDir>
#include <QSqlDatabase>
#include <QSqlQueryModel>
#include <QAbstractListModel>

#include "diaryentry.h"
#include "../Settings/importmodel.h"

class DiaryListModel : public QAbstractListModel
{
    Q_OBJECT
    Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
    Q_PROPERTY(bool bCanFetchMore READ bCanFetchMore NOTIFY bCanFetchMoreChanged)
    Q_PROPERTY(quint8 internationalUnit READ internationalUnit WRITE setInternationalUnit NOTIFY internationalUnitChanged)
    Q_PROPERTY(bool selectedGrams READ selectedGrams WRITE setSelectedGrams NOTIFY selectedGramsChanged)
    Q_PROPERTY(quint8 convValueMealCarbs READ convValueMealCarbs WRITE setConvValueMealCarbs NOTIFY convValueMealCarbsChanged)

public:
    enum Roles{
        RoleCreatedTimeStamp,
        RoleCreatedTime,
        RoleCreatedDate,
        RoleGlucMeasValueMg,
        RoleGlucMeasValueMmol,
        RoleMealCarbs,
        RoleMealCarbsGrams,
        RoleBolus,
        RoleBasalInjection,
        RoleTemporaryPumpBasal,
        RoleNote,
        RoleId
    };
    explicit DiaryListModel(QObject *parent = 0);
    ~DiaryListModel();

    Q_INVOKABLE void createEntry(const QVariantMap &values);
    Q_INVOKABLE void updateEntry(const int &id,const QVariantMap &values);
    Q_INVOKABLE bool deleteEntry(const int &id);
    Q_INVOKABLE void acceptImportedModel();

    Q_INVOKABLE QString exportToCsv();
    Q_INVOKABLE bool deleteDataBase();
    Q_INVOKABLE void reloadAndFetchMore();
    Q_INVOKABLE bool convAllMealCarbs();

    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    QHash<int, QByteArray> roleNames() const;

Q_SIGNALS:
    void countChanged();
    void bCanFetchMoreChanged();
    void internationalUnitChanged();
    void dataBaseChanged();
    void selectedGramsChanged();
    void convValueMealCarbsChanged();

public slots:

protected:
    bool bCanFetchMore();
    quint8 internationalUnit();
    void setInternationalUnit(const quint8 &unit);

    bool selectedGrams();
    void setSelectedGrams(const bool selectedValue);

    quint8 convValueMealCarbs();
    void setConvValueMealCarbs(const quint8 &value);

private:
    //SQLITE-DB
    bool m_bCanFetchMore;
    QSqlDatabase m_db;
    QSqlQueryModel* m_SqlTableEntries;
    void readSqlData();
    bool importFromDD(const QString &importFileName);
    bool importFromMySugr(const QString &importFileName);
    int indexOfId(const int &id);
    bool m_internationalUnit; //mmol/l
    bool m_selectedGrams;
    quint8 m_convValueMealCarbs;
    QString m_exportFile;

    QList<DiaryEntry*> m_diarylist;
};

#endif // DIARYLISTMODEL_H
