#include <QDebug>
#include <QRegExp>
#include <QTextCodec>
#include <QObject>
#include <QThread>
#include <QFile>
#include <QFileInfo>

#include "importmodel.h"
#include "../Database/databaseworker.h"
#include "../Diary/diarylistmodel.h"
#include "../Database/importworker.h"

#include "../constants.h"

#include "math.h"

ImportModel::ImportModel(QObject *parent)
    : QAbstractListModel(parent)
    , m_success(false)
{

}
ImportModel::~ImportModel(){

}

void ImportModel::importFromCsv(const QString &importFileName,const int &selectedDBType, const int &convValue){

    QFile importFile(importFileName);
    QFileInfo fileInfo(importFile);
    if (fileInfo.suffix().operator !=("csv")){
        emit error("Error: Wrong file format!");
        qWarning() << "Wrong data type!!!";
        return;
    }
    if (selectedDBType == 0){
        qDebug() << "importFromCsv";
        m_success = importDataFromDD(importFileName,convValue);
    }
    else if(selectedDBType == 1){
        m_success = importDataFromMySugr(importFileName);
    }
    Q_EMIT successChanged();
}
QList<QStringList> ImportModel::parseCsv(const QString &importFileName){
    QList<QStringList> data;
    QFile csvFile(importFileName);
    qDebug() << importFileName;
    bool isOpen = csvFile.open(QIODevice::ReadOnly);
    qDebug() << isOpen;
    if(!isOpen){
        emit error("Error: file can not be opened!");
        qWarning() << csvFile.error();
        return data;
    }
    QTextStream reader(&csvFile);

    QString header = reader.readLine();

    if (header.endsWith("\"")) {
        QStringList headerList = header.replace("\",","\";").split(";");
        data.append(headerList);
    }
    else {
        emit error("Error(1): csv file can not be read!");
        qWarning() << "Wrong Header end";
        return data;
    }

    while (!reader.atEnd()){
        QString line=reader.readLine();
        if(!line.endsWith("\"\"") && !line.endsWith("\"")) {
            QString newline = reader.readLine();
            line.remove(line.length(),1);
            line = line + ", " + newline;
        }
        line.remove(0,1); //remove first "
        line.remove(line.length()-1,1); //remove last "
        QStringList list=line.replace("\",","\";").split("\";\"");
        data.append(list);
    }
    csvFile.close();
}


bool ImportModel::importDataFromMySugr(const QString &importFileName){
    QLocale c(QLocale::system());
    QList<QStringList> csvData = parseCsv(importFileName);
    QStringList headerList=csvData.at(0);

    if (csvData.at(0).size() != 25){
        qWarning() << "Wrong Header";
        emit error("Error(2): csv file can not be read!");
        return false;
    }
    bool isIntUnit;
    if (headerList.at(3).contains("mg/dl",Qt::CaseInsensitive)) isIntUnit = false;
    else if (headerList.at(3).contains("mmol/l",Qt::CaseInsensitive)) isIntUnit = true;
    else {
        qWarning() << "Wrong measurement unit";
        emit error("Error(3): csv file can not be read!");
        return false;
    }

    for(int i = 1; i < csvData.size(); i++){
        DiaryEntry *entry = new DiaryEntry();
        QStringList splitString = csvData.at(i);
        QStringList notes;

        QDate entryDate = QDate::fromString(splitString.at(MYSUGR_IDX_DATE),"dd.MM.yyyy");
        QTime entryTime = QTime::fromString(splitString.at(MYSUGR_IDX_TIME),"hh:mm:ss");
        QDateTime createdStamp;
        createdStamp.setDate(entryDate);
        createdStamp.setTime(entryTime);

        if (createdStamp.isValid()){
            entry->setCreatedTimeStamp(createdStamp);
            entry->setCreatedDate(entry->createdTimeStamp().date());
            entry->setCreatedTime(entry->createdTimeStamp().time());

            double value = c.toDouble(splitString.at(MYSUGR_IDX_GLUCOSE));
            if (!isIntUnit){
                entry->setGlucMeasValueMg(value);
                entry->setGlucMeasValueMmol(value/MEASUREMENT_CONV_FACTOR);
            }
            else{
                entry->setGlucMeasValueMg(value*MEASUREMENT_CONV_FACTOR);
                entry->setGlucMeasValueMmol(value);
            }
            value = c.toDouble(splitString.at(MYSUGR_IDX_MEALCARBS));
            entry->setMealCarbs(value);
            value = c.toDouble(splitString.at(MYSUGR_IDX_BOLUS_1)) +
                    c.toDouble(splitString.at(MYSUGR_IDX_BOLUS_2)) +
                    c.toDouble(splitString.at(MYSUGR_IDX_BOLUS_3)) +
                    c.toDouble(splitString.at(MYSUGR_IDX_BOLUS_4));
            entry->setBolus(value);
            value = c.toDouble(splitString.at(MYSUGR_IDX_BASALINJECT));
            entry->setBasalInjection(value);
            QString str = "";
            notes << splitString.at(MYSUGR_IDX_NOTE_1) << splitString.at(MYSUGR_IDX_NOTE_2) << splitString.at(MYSUGR_IDX_NOTE_3);
            for (int j = 0; j < notes.count(); j++){
                if (!notes.at(j).isEmpty()){
                    str = str + notes.at(j) + " ";
                }
            }
            entry->setNote(str);
            str = "";
            //temp. basal rate
            str = splitString.at(MYSUGR_IDX_TEMP_PUMP_DURATION_MIN);
            if(!str.isEmpty()){
                int hours = (int)str.toInt() / 60;
                int min = str.toInt() % 60;
                QString per = splitString.at(MYSUGR_IDX_TEMP_PUMP_PERCENT);
                int percent = per.left(per.length() - 1).toInt();

                percent = percent - (percent % 5);
                min = min - (min % 5);
                if(hours < 10) str = "0" + QString::number(hours);
                else if (hours == 0) str = "00";
                else str = QString::number(hours);
                if (min < 10) str = str +":0"+ QString::number(min);
                else if(min == 0) str = str +":00";
                else str = str +":"+ QString::number(min);
                if (percent < 10) str = str + "/0"+QString::number(percent)+"%";
                else str = str + "/"+QString::number(percent)+"%";
                entry->setTemporaryPumpBasal(str);
            }
            str.clear();
            beginInsertRows(QModelIndex(),m_imports.count(),m_imports.count());
            m_imports.append(entry);
            endInsertRows();
        }
        else {
            emit error("Error(4): csv file can not be read!");
            return false;
        }
    }
    Q_EMIT countChanged();

    return true;
}
bool ImportModel::importDataFromDD(const QString &importFileName, const int &convValue){
    qDebug() << "importDataFromDD";
    QList<QStringList> csvData = parseCsv(importFileName);

    if (csvData.at(0).size() != 9){
        qWarning() << "Falsche Datei";
        emit error("Error(5): csv file can not be read!");
        return false;
    }
    bool isGram;
    if (csvData.at(0).at(4).contains("(g)",Qt::CaseInsensitive)) isGram = true;
    else isGram = false;
    qDebug() << isGram;
    for(int i=1; i < csvData.size(); i++){
        DiaryEntry *entry = new DiaryEntry();
        QStringList splitString = csvData.at(i);
        QString localString = splitString.at(0) + " " + splitString.at(1);
        QDate entryDate = QDate::fromString(splitString.at(0),"dd.MM.yyyy");
        QTime entryTime = QTime::fromString(splitString.at(1),Qt::SystemLocaleShortDate);
        QDateTime createdStamp;
        createdStamp.setDate(entryDate);
        createdStamp.setTime(entryTime);
        if (createdStamp.isValid()){
            entry->setCreatedTimeStamp(createdStamp);
            entry->setCreatedDate(entry->createdTimeStamp().date());
            entry->setCreatedTime(entry->createdTimeStamp().time());
            entry->setGlucMeasValueMg(splitString.at(2).toDouble());
            entry->setGlucMeasValueMmol(splitString.at(3).toDouble());
            if (isGram){
                entry->setMealCarbsGrams(splitString.at(4).toDouble());
                entry->setMealCarbs(entry->mealCarbsGrams() / convValue);
            }
            else{
                entry->setMealCarbs(splitString.at(4).toDouble());
                entry->setMealCarbsGrams(entry->mealCarbs() * convValue);
            }
            entry->setBolus(splitString.at(5).toDouble());
            entry->setTemporaryPumpBasal(splitString.at(6));
            entry->setBasalInjection(splitString.at(7).toDouble());
            entry->setNote(splitString.at(8));
            beginInsertRows(QModelIndex(),m_imports.count(),m_imports.count());
            m_imports.append(entry);
            endInsertRows();

            splitString.clear();
            localString.clear();
        }
        else {
            emit error("Error(6): csv file can not be read!");
            return false;
        }
    }
    Q_EMIT countChanged();
    return true;
}


int ImportModel::rowCount(const QModelIndex &parent) const{
    Q_UNUSED(parent)
    return m_imports.count();
}
QVariant ImportModel::data(const QModelIndex &index, int role) const{
    switch(role){
    case DiaryListModel::RoleCreatedTimeStamp:
        return m_imports.at(index.row())->createdTimeStamp();
    case DiaryListModel::RoleCreatedTime:
        return m_imports.at(index.row())->createdTime();
    case DiaryListModel::RoleCreatedDate:
        return m_imports.at(index.row())->createdDate();
    case DiaryListModel::RoleGlucMeasValueMg:
        return m_imports.at(index.row())->glucMeasValueMg();
    case DiaryListModel::RoleGlucMeasValueMmol:
        return m_imports.at(index.row())->glucMeasValueMmol();
    case DiaryListModel::RoleMealCarbs:
        return m_imports.at(index.row())->mealCarbs();
    case DiaryListModel::RoleMealCarbsGrams:
        return m_imports.at(index.row())->mealCarbsGrams();
    case DiaryListModel::RoleBolus:
        return m_imports.at(index.row())->bolus();
    case DiaryListModel::RoleBasalInjection:
        return m_imports.at(index.row())->basalInjection();
    case DiaryListModel::RoleTemporaryPumpBasal:
        return m_imports.at(index.row())->temporaryPumpBasal();
    case DiaryListModel::RoleNote:
        return m_imports.at(index.row())->note();
    case DiaryListModel::RoleId:
        return m_imports.at(index.row())->id();
    }
    return QVariant();
}
QHash<int, QByteArray> ImportModel::roleNames() const{
    QHash<int, QByteArray> roles;
    roles.insert(DiaryListModel::RoleCreatedTimeStamp,"timeStamp");
    roles.insert(DiaryListModel::RoleCreatedTime,"time");
    roles.insert(DiaryListModel::RoleCreatedDate,"date");
    roles.insert(DiaryListModel::RoleGlucMeasValueMg,"glucoseMeasurementMg");
    roles.insert(DiaryListModel::RoleGlucMeasValueMmol,"glucoseMeasurementMmol");
    roles.insert(DiaryListModel::RoleMealCarbs,"mealCarbs");
    roles.insert(DiaryListModel::RoleMealCarbsGrams,"mealCarbsGrams");
    roles.insert(DiaryListModel::RoleBolus,"bolus");
    roles.insert(DiaryListModel::RoleBasalInjection,"basalInjection");
    roles.insert(DiaryListModel::RoleTemporaryPumpBasal,"temporaryPumpBasal");
    roles.insert(DiaryListModel::RoleNote,"note");
    roles.insert(DiaryListModel::RoleId,"id");
    return roles;
}
bool ImportModel::success(){
    return m_success;
}
void ImportModel::startImport(){
    Q_EMIT importingStarted();
    if(!DatabaseWorker::instance()->deleteAllEntries()){
        qWarning() << "Fehler beim Löschen des Tables";
        Q_EMIT importingFinished();
        return;
    }

    DatabaseWorker::instance()->closeDatabase();
    QThread *thread = new QThread();
    ImportWorker * worker = new ImportWorker(m_imports);
    worker->moveToThread(thread);

    qRegisterMetaType< DiaryEntry* >("DiaryEntry*");
    connect(thread, &QThread::started, this, &ImportModel::importingStarted);
    connect(thread, &QThread::started, worker, &ImportWorker::slotExecute);
    connect(worker, &ImportWorker::progress, this, &ImportModel::importProgress);
    connect(thread, &QThread::finished, this, &ImportModel::importingFinished);
    connect(worker, &ImportWorker::finished, thread, &QThread::quit );
    connect(thread, &QThread::finished, worker, &ImportWorker::deleteLater);
    connect(thread, &QThread::finished, thread, &QThread::deleteLater);
    thread->start(QThread::NormalPriority);
}
