#ifndef IMPORTMODEL_H
#define IMPORTMODEL_H

#include <QAbstractListModel>
#include "../Diary/diaryentry.h"

class ImportModel : public QAbstractListModel
{
    Q_OBJECT
    Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
    Q_PROPERTY(bool success READ success NOTIFY successChanged)

public:
    explicit ImportModel(QObject *parent = 0);
    ~ImportModel();

    Q_INVOKABLE void importFromCsv(const QString &importFileName,const int &selectedDBType, const int &convValue);
    Q_INVOKABLE void startImport();

    bool importDataFromDD(const QString &importFileName, const int &convValue);
    bool importDataFromMySugr(const QString &importFileName);

    QList<QStringList> parseCsv(const QString &importFileName);

    bool success();

    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    QHash<int, QByteArray> roleNames() const;

signals:
    void countChanged();
    void successChanged();
    void importProgress(quint64 importedCount);
    void importingStarted();
    void importingFinished();
    void error(QString errorString);

protected:

private:
    QList<DiaryEntry*> m_imports;
    bool m_success;
};

#endif // IMPORTMODEL_H
