#include <QDebug>
#include "pumpbasalmodel.h"
#include "pumpbasal.h"

#include <libintl.h>
#include "../constants.h"
#include "../Database/databaseworker.h"

PumpBasalModel::PumpBasalModel(QObject *parent)
    : QAbstractListModel(parent)
    , m_bCanFetchMore(false)
    , m_SqlTablePmp(new QSqlQueryModel())
    , m_activeId(-1)
{
   readSqlData();
}
PumpBasalModel::~PumpBasalModel(){
    m_SqlTablePmp->clear();
}
void PumpBasalModel::readSqlData(){
    m_SqlTablePmp = DatabaseWorker::instance()->getAllPumpRates();
    if (m_bCanFetchMore != m_SqlTablePmp->canFetchMore()){
        m_bCanFetchMore = m_SqlTablePmp->canFetchMore();
        Q_EMIT bCanFetchMoreChanged();
    }
    for (int rowIdx = 0; rowIdx < m_SqlTablePmp->rowCount(); rowIdx++){
        PumpBasal *newBasal = new PumpBasal(this);
        newBasal->setId(m_SqlTablePmp->data(m_SqlTablePmp->index(rowIdx,IDX_PUMPBASAL_ID)).toInt());
        newBasal->setName(m_SqlTablePmp->data(m_SqlTablePmp->index(rowIdx,IDX_PUMPBASAL_NAME)).toString());
        newBasal->setBasalRate(m_SqlTablePmp->data(m_SqlTablePmp->index(rowIdx,IDX_PUMPBASAL_RATE)).toString());
        newBasal->setIsActive(m_SqlTablePmp->data(m_SqlTablePmp->index(rowIdx,IDX_PUMPBASAL_ISACT)).toBool());
        beginInsertRows(QModelIndex(),m_basal.count(),m_basal.count());
        m_basal.append(newBasal);
        endInsertRows();
    }
    Q_EMIT countChanged();
}
void PumpBasalModel::reloadAndFetchMore(){
    if(m_bCanFetchMore){
        m_SqlTablePmp->fetchMore();
        if (m_bCanFetchMore != m_SqlTablePmp->canFetchMore()){
            m_bCanFetchMore = m_SqlTablePmp->canFetchMore();
            Q_EMIT bCanFetchMoreChanged();
        }
        for (int rowIdx = rowCount(); rowIdx < m_SqlTablePmp->rowCount(); rowIdx++){
            PumpBasal *newBasal = new PumpBasal(this);
            newBasal->setId(m_SqlTablePmp->data(m_SqlTablePmp->index(rowIdx,IDX_PUMPBASAL_ID)).toInt());
            newBasal->setName(m_SqlTablePmp->data(m_SqlTablePmp->index(rowIdx,IDX_PUMPBASAL_NAME)).toString());
            newBasal->setBasalRate(m_SqlTablePmp->data(m_SqlTablePmp->index(rowIdx,IDX_PUMPBASAL_RATE)).toString());
            newBasal->setIsActive(m_SqlTablePmp->data(m_SqlTablePmp->index(rowIdx,IDX_PUMPBASAL_ISACT)).toBool());
            beginInsertRows(QModelIndex(),m_basal.count(),m_basal.count());
            m_basal.append(newBasal);
            endInsertRows();
        }
    }
    Q_EMIT countChanged();
}

int PumpBasalModel::rowCount(const QModelIndex &parent) const{
    Q_UNUSED(parent)
    return m_basal.count();
}
void PumpBasalModel::createBasal(const QString &title, const QString &basalString,const bool &isAct){
    PumpBasal *newBasal = new PumpBasal(this);

    newBasal->setName(title);
    newBasal->setBasalRate(basalString);
    newBasal->setIsActive(isAct);

    int newId = DatabaseWorker::instance()->savePumpEntry(newBasal);
    if(newId != -1){
        newBasal->setId(newId);
        beginInsertRows(QModelIndex(),m_basal.count(),m_basal.count());
        m_basal.append(newBasal);
        endInsertRows();
        Q_EMIT countChanged();
    }
}
void PumpBasalModel::copyBasal(const QString &title, const QString &basalString){
    QString newName = gettext("Copy of ") + title;
    createBasal(newName,basalString,false);
}


void PumpBasalModel::updateBasal(const int &id, const QString &title, const QString &basalString,const bool &isAct){
    int idx = indexOfId(id);
    PumpBasal *basal = m_basal.value(idx);

    basal->setName(title);
    basal->setBasalRate(basalString);
    basal->setIsActive(isAct);

    int res = DatabaseWorker::instance()->updatePumpEntry(basal);
    if (res != -1){
        emit dataChanged(index(m_basal.indexOf(basal)), index(m_basal.indexOf(basal)));
    }
}
QVariant PumpBasalModel::data(const QModelIndex &index, int role) const{
    switch(role){
    case RoleId:
        return m_basal.at(index.row())->id();
    case RoleName:
        return m_basal.at(index.row())->name();
    case RoleBasal:
        return m_basal.at(index.row())->basalRate();
    case RoleActive:
        return m_basal.at(index.row())->isActive();
    }
    return QVariant();
}
void PumpBasalModel::removeBasal(int id) {
   if (DatabaseWorker::instance()->deletePumpEntry(id)){
       int idx = indexOfId(id);
       emit beginRemoveRows(QModelIndex(),idx,idx);
       m_basal.takeAt(idx)->deleteLater();
       emit endRemoveRows();
       Q_EMIT countChanged();
   }
}
QHash<int, QByteArray> PumpBasalModel::roleNames() const{
    QHash<int, QByteArray> roles;
    roles.insert(RoleId,"id");
    roles.insert(RoleName,"name");
    roles.insert(RoleBasal,"basal");
    roles.insert(RoleActive,"active");
    return roles;
}
bool PumpBasalModel::bCanFetchMore(){
    return m_bCanFetchMore;
}
int PumpBasalModel::indexOfId(const int &id){
    for (int i = 0; i < m_basal.size(); i++) {
        if (id == m_basal[i]->id())
            return i;
    }
    return -1;
}
