#ifndef PUMPBASALMODEL_H
#define PUMPBASALMODEL_H

#include <QObject>
#include <QSqlDatabase>
#include <QAbstractListModel>
#include <QSqlQueryModel>

class PumpBasal;

class PumpBasalModel : public QAbstractListModel
{
    Q_OBJECT
    Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
    Q_PROPERTY(bool bCanFetchMore READ bCanFetchMore NOTIFY bCanFetchMoreChanged)

public:
    enum Roles{
        RoleId,
        RoleName,
        RoleBasal,
        RoleActive
    };

    explicit PumpBasalModel(QObject *parent = 0);
    ~PumpBasalModel();
    Q_INVOKABLE void createBasal(const QString &title,const QString &basalString,const bool &isAct);
    Q_INVOKABLE void updateBasal(const int &id,const QString &title,const QString &basalString,const bool &isAct);
    Q_INVOKABLE void copyBasal(const QString &title,const QString &basalString);
    Q_INVOKABLE void removeBasal(int id);
    Q_INVOKABLE void reloadAndFetchMore();

    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    QHash<int, QByteArray> roleNames() const;

protected:
    bool bCanFetchMore();

signals:
    void countChanged();
    void bCanFetchMoreChanged();

public slots:
    //void changeOldActiveId(bool act);

private:
    QList<PumpBasal*> m_basal;
    QSqlQueryModel* m_SqlTablePmp;

    bool m_bCanFetchMore;
    quint64 m_activeId;

    void createTable();
    void readSqlData();
    int indexOfId(const int &id);
};

#endif // PUMPBASALMODEL_H
