#ifndef DIARYSTATISTICS_H
#define DIARYSTATISTICS_H

#include <QObject>
#include <QSqlQueryModel>


class DiaryStatistics : public QObject
{
    Q_OBJECT
    Q_PROPERTY(QString measurementUnit READ measurementUnit WRITE setMeasurementUnit NOTIFY measurementUnitChanged)
    Q_PROPERTY(bool diabetesTherapy READ diabetesTherapy WRITE setDiabetesTherapy NOTIFY diabetesTherapyChanged)
    Q_PROPERTY(quint64 numberOfEntries READ numberOfEntries NOTIFY numberOfEntriesChanged)

    Q_PROPERTY(double measurementAverageWeek READ measurementAverageWeek NOTIFY measurementAverageChanged)
    Q_PROPERTY(double measurementAverageMonth READ measurementAverageMonth NOTIFY measurementAverageChanged)
    Q_PROPERTY(double measurementAverageQuarter READ measurementAverageQuarter NOTIFY measurementAverageChanged)
    Q_PROPERTY(double measurementAbove READ measurementAbove NOTIFY measurementOutsideChanged)
    Q_PROPERTY(double measurementBelow READ measurementBelow NOTIFY measurementOutsideChanged)
    Q_PROPERTY(double measurementOutside READ measurementOutside NOTIFY measurementOutsideChanged)
    Q_PROPERTY(double hba1c READ hba1c NOTIFY hba1cChanged)
    Q_PROPERTY(double insulinAverageWeek READ insulinAverageWeek NOTIFY insulinAverageChanged)
    Q_PROPERTY(double insulinAverageMonth READ insulinAverageMonth NOTIFY insulinAverageChanged)
    Q_PROPERTY(double insulinAverageQuarter READ insulinAverageQuarter NOTIFY insulinAverageChanged)
    Q_PROPERTY(double carbsAverageWeek READ carbsAverageWeek NOTIFY carbsAverageChanged)
    Q_PROPERTY(double carbsAverageMonth READ carbsAverageMonth NOTIFY carbsAverageChanged)
    Q_PROPERTY(double carbsAverageQuarter READ carbsAverageQuarter NOTIFY carbsAverageChanged)
    Q_PROPERTY(double bolusRatio READ bolusRatio NOTIFY ratioChanged)
    Q_PROPERTY(double basalRatio READ basalRatio NOTIFY ratioChanged)

public:
    explicit DiaryStatistics(QObject *parent = 0);

    Q_INVOKABLE void setStatistics();
    Q_INVOKABLE void measurementOutsideRefresh(const double &minValue, const double &maxValue);

signals:
    void numberOfEntriesChanged();
    void measurementUnitChanged();
    void diabetesTherapyChanged();
    void measurementAverageChanged();
    void measurementOutsideChanged();
    void insulinAverageChanged();
    void carbsAverageChanged();
    void ratioChanged();
    void hba1cChanged();

protected:
    quint64 numberOfEntries();

    QString measurementUnit();
    void setMeasurementUnit(const QString &u);

    bool diabetesTherapy();
    void setDiabetesTherapy(const bool &therapy);

    double measurementAverageWeek();
    double measurementAverageMonth();
    double measurementAverageQuarter();

    double measurementAbove();
    double measurementBelow();
    double measurementOutside();
    double hba1c();

    double insulinAverageWeek();
    double insulinAverageMonth();
    double insulinAverageQuarter();

    double carbsAverageWeek();
    double carbsAverageMonth();
    double carbsAverageQuarter();

    double bolusRatio();
    double basalRatio();

public slots:
    //void refreshStatistics(QString &unit);

private:
    QSqlQueryModel* m_model;
    void openDatabase();
    void readSqlData();

    double columnAverage(const int &columnIdx, const QString &duration);
    double columnSum(const int &columnIdx, const int &days);

    quint64 m_numberOfEntries;
    QString m_measurementUnit;
    bool m_diabetesTherapy;

    double m_measurementAverageWeek;
    double m_measurementAverageMonth;
    double m_measurementAverageQuarter;

    double m_measurementAbove;
    double m_measurementBelow;
    double m_measurementOutside;
    double m_hba1c;
    double m_insulinAverageWeek;
    double m_insulinAverageMonth;
    double m_insulinAverageQuarter;
    double m_carbsAverageWeek;
    double m_carbsAverageMonth;
    double m_carbsAverageQuarter;
    double m_basalRatio;
    double m_bolusRatio;
};

#endif // DIARYSTATISTICS_H
