#ifndef CONFIG
#define CONFIG

static const QVariant SQLNULL = QVariant(QVariant::String);
static const quint8 FIXPOINT = 1;
static const QString DATABASENAME = "diabetesDiaryDB";

//pump-basal-model
static const quint8 IDX_PUMPBASAL_ID    = 0;
static const quint8 IDX_PUMPBASAL_NAME  = 1;
static const quint8 IDX_PUMPBASAL_RATE  = 2;
static const quint8 IDX_PUMPBASAL_ISACT = 3;
static const QString QUERY_PUMPBASAL_INSERT       = "INSERT INTO pump_basal_rate VALUES(NULL,?,?,?)";
static const QString QUERY_PUMPBASAL_UPDATE_BY_ID = "UPDATE pump_basal_rate SET name=?,basalrate=?,active=? WHERE id=?";
static const QString QUERY_PUMPBASAL_DELETE_BY_ID = "DELETE FROM pump_basal_rate WHERE id=?";
static const QString QUERY_GET_ALL_PUMPBASAL      = "SELECT * FROM pump_basal_rate";
static const QString QUERY_GET_AUTOINCID_PUMP = "SELECT seq FROM sqlite_sequence WHERE name = 'pump_basal_rate'";

//entries
static const quint8 IDX_ENTRIES_ID             = 0;
static const quint8 IDX_ENTRIES_CREATEDTIME    = 1;
static const quint8 IDX_ENTRIES_DATE           = 2;
static const quint8 IDX_ENTRIES_TIME           = 3;
static const quint8 IDX_ENTRIES_GLUCOSE_MG     = 4;
static const quint8 IDX_ENTRIES_GLUCOSE_MMOL   = 5;
static const quint8 IDX_ENTRIES_MEALCARBS      = 6;
static const quint8 IDX_ENTRIES_BOLUS          = 7;
static const quint8 IDX_ENTRIES_TEMP_PUMPBASAL = 8;
static const quint8 IDX_ENTRIES_BASALINJECT    = 9;
static const quint8 IDX_ENTRIES_NOTE           = 10;
static const QString QUERY_GET_ALL_ENTRIES_ORDER_BY_DATE = "SELECT * FROM entries ORDER BY createdTimeStamp DESC";
static const QString QUERY_ENTRIES_INSERT                = "INSERT INTO entries VALUES (NULL,?,?,?,?,?,?,?,?,?,?)";
static const QString QUERY_ENTRIES_UPDATE_BY_ID          = "UPDATE entries SET createdTimeStamp=?,"
                                                                               "date=?,"
                                                                               "time=?,"
                                                                               "glucoseMeasurementMg=?,"
                                                                               "glucoseMeasurementMmol=?,"
                                                                               "mealCarbs=?,"
                                                                               "bolus=?,"
                                                                               "temporaryPumpBasal=?,"
                                                                               "basalInjection=?,"
                                                                               "note=? "
                                                                               "WHERE id=?";
static const QString QUERY_ENTRIES_DELETE_BY_ID          = "DELETE FROM entries WHERE id=?";
static const QString QUERY_GET_AUTOINCID_ENTRIES         = "SELECT seq FROM sqlite_sequence WHERE name = 'entries'";

static const QString VARNAME_ENTRIES_DATE           = "date";
static const QString VARNAME_ENTRIES_GLUCOSE        = "glucoseMeasurement";
static const QString VARNAME_ENTRIES_MEALCARBS      = "mealCarbs";
static const QString VARNAME_ENTRIES_BOLUS          = "bolus";
static const QString VARNAME_ENTRIES_TEMP_PUMPBASAL = "temporaryPumpBasal";
static const QString VARNAME_ENTRIES_BASALINJECT    = "basalInjection";
static const QString VARNAME_ENTRIES_NOTE           = "note";

static const QString QUERY_SUM_BOLUS = "SELECT SUM("+ VARNAME_ENTRIES_BOLUS +") FROM entries;";
static const QString QUERY_SUM_BASAL = "SELECT SUM("+ VARNAME_ENTRIES_BASALINJECT +") FROM entries;";

static const float MEASUREMENT_CONV_FACTOR = 18.1;

//version
static const QString QUERY_GET_VERSION    = "SELECT * FROM version";
static const QString QUERY_UPDATE_VERSION = "UPDATE version SET version = ?";

//settings
static const QString QUERY_GET_SETTING    = "SELECT value FROM settings WHERE setting=?";
static const QString QUERY_UPDATE_SETTING = "INSERT OR REPLACE INTO settings VALUES (?,?)";
static const QString VARNAME_SETTINGS_MEALCARBS_CONVVALUE = "mealCarbsConvValue";
static const QString VARNAME_SETTINGS_SELECTEDMEALCARBSGRAMS = "selectedMealCarbs";

//table
static const QString QUERY_DELETE_TABLE_ENTRIES   = "DROP TABLE IF EXISTS entries";
static const QString QUERY_DELETE_TABLE_PUMPBASAL = "DROP TABLE IF EXISTS pump_basal_rate";
static const QString QUERY_CREATE_TABLE_PUMPBASAL = "CREATE TABLE IF NOT EXISTS pump_basal_rate("
                                                    "id INTEGER PRIMARY KEY AUTOINCREMENT, "
                                                    "name TEXT, "
                                                    "basalrate TEXT, "
                                                    "active TEXT)";
static const QString QUERY_CREATE_TABLE_ENTRIES = "CREATE TABLE IF NOT EXISTS entries("
                                                  "id INTEGER PRIMARY KEY AUTOINCREMENT, "
                                                  "createdTimeStamp TIMESTAMP, "
                                                  "date TEXT,"
                                                  "time TEXT,"
                                                  "glucoseMeasurementMg TEXT, "
                                                  "glucoseMeasurementMmol TEXT, "
                                                  "mealCarbs TEXT, "
                                                  "bolus TEXT, "
                                                  "temporaryPumpBasal TEXT, "
                                                  "basalInjection TEXT, "
                                                  "note TEXT)";
static const QString QUERY_CREATE_TABLE_VERSION = "CREATE TABLE IF NOT EXISTS version(version INTEGER)";
static const QString QUERY_CREATE_TABLE_APPSETTINGS = "CREATE TABLE IF NOT EXISTS settings(setting TEXT UNIQUE, value TEXT)";

//MySugr
static const quint8 MYSUGR_IDX_DATE = 0;
static const quint8 MYSUGR_IDX_TIME = 1;
static const quint8 MYSUGR_IDX_GLUCOSE = 3;
static const quint8 MYSUGR_IDX_BOLUS_1 = 4;
static const quint8 MYSUGR_IDX_BOLUS_2 = 6;
static const quint8 MYSUGR_IDX_BOLUS_3 = 7;
static const quint8 MYSUGR_IDX_BOLUS_4 = 8;
static const quint8 MYSUGR_IDX_BASALINJECT    = 5;
static const quint8 MYSUGR_IDX_MEALCARBS      = 11;
static const quint8 MYSUGR_IDX_TEMP_PUMP_PERCENT = 9;
static const quint8 MYSUGR_IDX_TEMP_PUMP_DURATION_MIN = 10;
static const quint8 MYSUGR_IDX_NOTE_1 = 12;
static const quint8 MYSUGR_IDX_NOTE_2 = 15;
static const quint8 MYSUGR_IDX_NOTE_3 = 17;


#endif // CONFIG

